/*  Tools Plus (Version 3.0) supplemental file
 *  Copyright (c) 1989-96 Waters Edge Software
 *
 *  This source file must be compiled as part of any project that uses
 *	Tools Plus libraries.
 *
 *	This file provides access to the SystemVersion routine. It returns a double
 *	whose format is consistent with your compiler settings (standard, native, or
 *	for a math co-processor).
 *
 *	This file also contains routines that are necessary to use C strings as
 *	parameters in Tools Plus routines (see the ToolsPlus.h file for details).
 */


#include "ToolsPlus.h"


#ifdef __cplusplus
extern "C" {
#endif
 	
 	


/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *	S y s t e m V e r s i o n :
 *
 *	The SystemVersion function returns the System File's version as an 'double' type
 *	floating-point number.  This source code, when compiled, will produce an
 *	appropriate "double" type floating-point number whose format is determined by
 *	your compiler's settings (ie: standard, native, compiled for a math co-processor
 *	or not).				
 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 	pascal short _SYSV(void);									/*PRIVATE:	This function obtains the	*/
 																						/*	System file's version number as a	*/
 																						/*	short (used by the SystemVersion	*/
 																						/*	routine).													*/
	pascal double SystemVersion(void)
 	{
 	return (_SYSV() / 100.0);									/* Get System Version and convert to	*/
 	}																					/* a double type.											*/








/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *	C   S t r i n g s   I n   T o o l s   P l u s   P a r a m e t e r s
 *
 *	The following routines are Tools Plus "glue" routines. They are identical
 *	to their mixed case equivalents (i.e., windowopen and WindowOpen) except that
 *	these routines accept C strings as parameters instead of Pascal strings.
 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#if TOOLSPLUS_ALLOWS_CSTRINGS

#if TOOLSPLUS_USES_ONLY_CSTRINGS
/*
 *	Undefine all the #defines declared in ToolsPlus.h that are used to remap
 *	standard routine names to their lower case equivalents. We don't need them
 *	in this file.
 */
#undef	WindowOpen
#undef	WindowOpenRect
#undef	WindowTitle
#undef	NewButton
#undef	NewButtonRect
#undef	ButtonTitle
#undef	GetEditString
#undef	GetFieldString
#undef	PasteIntoField
#undef	NewFieldFilter
#undef	SetListBoxText
#undef	GetListBoxText
#undef	SearchListBox
#undef	NewPanel
#undef	NewPanelRect
#undef	AppleMenu
#undef	Menu
#undef	InsertMenuItm
#undef	GetMenuString
#undef	RenameItem
#undef	NewPopUp
#undef	NewPopUpRect
#undef	PopUpMenu
#undef	InsertPopUpItem
#undef	GetPopUpString
#undef	RenamePopUp
#undef	SetNotification
#undef	AlertBox
#undef	AlertBox3
#undef	AlertButtonName
#undef	GetIndexString
#undef	SetIndexString
#undef	InsertIndexString
#undef	StrInBox
#undef	StrInBoxRect
#undef	GetToolsPlusVersion

#endif // C strings only in Tools Plus routines


/*	Local routine for converting a C string to a Pascal string	*/
	static void CtoP(const char *Cstring, Str255 Pstring)
	{
		short charPos, PStringLength = 0;
		
		if (Pstring) {
			if (Cstring) {
				for (charPos = 1; *Cstring && charPos < 256; charPos++) {
					Pstring[charPos] = (unsigned char)*Cstring++;
					PStringLength++;
					}
				}
			Pstring[0] = (unsigned char)PStringLength;
		}
	}


/*	Local routine for converting a Pascal string to a C string	*/
	static void PtoC(const Str255 Pstring, char *Cstring)
	{
		char *charPtr = Cstring;
		short charPos, PStringLength;

		if (Cstring) {
			if (Pstring) {
				PStringLength = (short)Pstring[0];
				for (charPos = 1; charPos <= PStringLength; charPos++)
					*charPtr++ = (char)Pstring[charPos];
				}
			*charPtr = 0;
		}
	}


void windowopen (short Window, short left, short top, short right, short bottom, const char *Title, long Spec, Boolean goAwayFlag, Boolean modalFlag)
{
	Str255 pTitle;
	CtoP(Title, pTitle);
	WindowOpen (Window, left, top, right, bottom, pTitle, Spec, goAwayFlag, modalFlag);
}

void windowopenrect (short Window, const Rect *Bounds, const char *Title, long Spec, Boolean goAwayFlag, Boolean modalFlag)
{
	Str255 pTitle;
	CtoP(Title, pTitle);
	WindowOpenRect (Window, Bounds, pTitle, Spec, goAwayFlag, modalFlag);
}

void windowtitle (short Window, const char *Title)
{
	Str255 pTitle;
	CtoP(Title, pTitle);
	WindowTitle (Window, pTitle);
}

void newbutton (short Button, short left, short top, short right, short bottom, const char *Title, long Spec, Boolean EnabledFlag, Boolean SelectedFlag)
{
	Str255 pTitle;
	CtoP(Title, pTitle);
	NewButton (Button, left, top, right, bottom, pTitle, Spec, EnabledFlag, SelectedFlag);
}

void newbuttonrect (short Button, const Rect *Bounds, const char *Title, long Spec, Boolean EnabledFlag, Boolean SelectedFlag)
{
	Str255 pTitle;
	CtoP(Title, pTitle);
	NewButtonRect (Button, Bounds, pTitle, Spec, EnabledFlag, SelectedFlag);
}

void buttontitle (short Button, const char *Title)
{
	Str255 pTitle;
	CtoP(Title, pTitle);
	ButtonTitle (Button, pTitle);
}

void geteditstring (char *EditString)
{
	Str255 pEditString;
	GetEditString (pEditString);
	PtoC(pEditString, EditString);
}

void getfieldstring (short Field, char *EditString)
{
	Str255 pEditString;
	GetFieldString (Field, pEditString);
	PtoC(pEditString, EditString);
}

void pasteintofield (short Field, const char *Text, Boolean Replace)
{
	Str255 pText;
	CtoP(Text, pText);
	PasteIntoField (Field, pText, Replace);
}

short newfieldfilter (const char *Chars, long FilterSpec)
{
	Str255 pChars;
	CtoP(Chars, pChars);
	return NewFieldFilter (pChars, FilterSpec);
}

void setlistboxtext (short ListBox, short LineNum, const char *Text)
{
	Str255 pText;
	CtoP(Text, pText);
	SetListBoxText (ListBox, LineNum, pText);
}

void getlistboxtext (short ListBox, short LineNum, char *Text)
{
	Str255 pText;
	GetListBoxText (ListBox, LineNum, pText);
	PtoC(pText, Text);
}

short searchlistbox (short ListBox, const char *Text)
{
	Str255 pText;
	CtoP(Text, pText);
	return SearchListBox (ListBox, pText);
}

void newpanel (short Panel, short left, short top, short right, short bottom, const char *Title, long Spec, short ShadowWidth)
{
	Str255 pTitle;
	CtoP(Title, pTitle);
	NewPanel (Panel, left, top, right, bottom, pTitle, Spec, ShadowWidth);
}

void newpanelrect (short Panel, const Rect *Bounds, const char *Title, long Spec, short ShadowWidth)
{
	Str255 pTitle;
	CtoP(Title, pTitle);
	NewPanelRect (Panel, Bounds, pTitle, Spec, ShadowWidth);
}

void applemenu (const char *AboutName)
{
	Str255 pAboutName;
	CtoP(AboutName, pAboutName);
	AppleMenu (pAboutName);
}

void menu (short MenuNumber, short ItemNumber, Boolean EnabledFlag, const char *MenuText)
{
	Str255 pMenuText;
	CtoP(MenuText, pMenuText);
	Menu (MenuNumber, ItemNumber, EnabledFlag, pMenuText);
}

void insertmenuitm (short MenuNumber, short ItemNumber, Boolean EnabledFlag, const char *MenuText)
{
	Str255 pMenuText;
	CtoP(MenuText, pMenuText);
	InsertMenuItm (MenuNumber, ItemNumber, EnabledFlag, pMenuText);
}

void getmenustring (short MenuNumber, short ItemNumber, char *MenuText)
{
	Str255 pMenuText;
	GetMenuString (MenuNumber, ItemNumber, pMenuText);
	PtoC(pMenuText, MenuText);
}

void renameitem (short MenuNumber, short ItemNumber, const char *MenuText)
{
	Str255 pMenuText;
	CtoP(MenuText, pMenuText);
	RenameItem (MenuNumber, ItemNumber, pMenuText);
}

void newpopup (short MenuNumber, short left, short top, short right, short bottom, const char *MenuTitle, long Spec, Boolean EnabledFlag)
{
	Str255 pMenuTitle;
	CtoP(MenuTitle, pMenuTitle);
	NewPopUp (MenuNumber, left, top, right, bottom, pMenuTitle, Spec, EnabledFlag);
}

void newpopuprect (short MenuNumber, const Rect *Bounds, const char *MenuTitle, long Spec, Boolean EnabledFlag)
{
	Str255 pMenuTitle;
	CtoP(MenuTitle, pMenuTitle);
	NewPopUpRect (MenuNumber, Bounds, pMenuTitle, Spec, EnabledFlag);
}

void popupmenu (short MenuNumber, short ItemNumber, Boolean EnabledFlag, const char *MenuText)
{
	Str255 pMenuText;
	CtoP(MenuText, pMenuText);
	PopUpMenu (MenuNumber, ItemNumber, EnabledFlag, pMenuText);
}

void insertpopupitem (short MenuNumber, short ItemNumber, Boolean EnabledFlag, const char *MenuText)
{
	Str255 pMenuText;
	CtoP(MenuText, pMenuText);
	InsertPopUpItem (MenuNumber, ItemNumber, EnabledFlag, pMenuText);
}

void getpopupstring (short MenuNumber, short ItemNumber, char *MenuText)
{
	Str255 pMenuText;
	GetPopUpString (MenuNumber, ItemNumber, pMenuText);
	PtoC(pMenuText, MenuText);
}

void renamepopup (short MenuNumber, short ItemNumber, const char *MenuText)
{
	Str255 pMenuText;
	CtoP(MenuText, pMenuText);
	RenamePopUp (MenuNumber, ItemNumber, pMenuText);
}

void setnotification (short IconID, short SoundID, const char *Message, Boolean ResetAfterUse)
{
	Str255 pMessage;
	CtoP(Message, pMessage);
	SetNotification (IconID, SoundID, pMessage, ResetAfterUse);
}

short alertbox (short theIcon, const char *AlertText, long AlertCode)
{
	Str255 pAlertText;
	CtoP(AlertText, pAlertText);
	return AlertBox (theIcon, pAlertText, AlertCode);
}

short alertbox3 (short theIcon, const char *AlertText, long AlertCode, const char *But1, const char *But2, const char *But3)
{
	Str255 pAlertText, pBut1, pBut2, pBut3;
	CtoP(AlertText, pAlertText);
	CtoP(But1, pBut1);
	CtoP(But2, pBut2);
	CtoP(But3, pBut3);
	return AlertBox3 (theIcon, pAlertText, AlertCode, pBut1, pBut2, pBut3);
}

void alertbuttonname (short Button, const char *Title)
{
	Str255 pTitle;
	CtoP(Title, pTitle);
	AlertButtonName (Button, pTitle);
}

void getindexstring (Handle hRec, short Index, char *Text)
{
	Str255 pText;
	GetIndexString (hRec, Index, pText);
	PtoC(pText, Text);
}

void setindexstring (Handle hRec, short Index, const char *Text)
{
	Str255 pText;
	CtoP(Text, pText);
	SetIndexString (hRec, Index, pText);
}

void insertindexstring (Handle hRec, short Index, const char *Text)
{
	Str255 pText;
	CtoP(Text, pText);
	InsertIndexString (hRec, Index, pText);
}

void strinbox (short left, short top, short right, short bottom, const char *Text, long DispSpec, short Just)
{
	Str255 pText;
	CtoP(Text, pText);
	StrInBox (left, top, right, bottom, pText, DispSpec, Just);
}

void strinboxrect (const Rect *Bounds, const char *Text, long DispSpec, short Just)
{
	Str255 pText;
	CtoP(Text, pText);
	StrInBoxRect (Bounds, pText, DispSpec, Just);
}

void gettoolsplusversion (char *Version)
{
	Str255 pVersion;
	GetToolsPlusVersion (pVersion);
	PtoC(pVersion, Version);
}

#endif



#ifdef __cplusplus
}
#endif