/*  Tools Plus (Version 3.0) Header file
 *  Copyright (C) 1989-96 Waters Edge Software
 *
 *  This header file defines all Tools Plus components (constants, variables and
 *	structures).  Programs using Tools Plus must include this header file.
 *
 *	This header can be used in conjunction with Apples original headers or with
 *	the new Universal Headers.  In places where this Tools Plus header uses the
 *	same name as an item in Apples original header (i.e., "inUpButton"), we
 *	#define the item in Tools Plus.h. This lets you use that item along with
 *	Apples original headers, and it also ensures that you will be able to use
 *	that same item if Apple renames it in a future version of their headers.


 *	Using Pascal Strings and/or C Strings in Tools Plus
 *	```````````````````````````````````````````````````
 *	By default, Tools Plus assumes that you will use only Pascal strings for
 *	parameters in Tools Plus routines (this is consistent with the Macintosh
 *	toolbox). You have the option of using Pascal strings only, C strings only,
 *	or a mix of either as required when calling Tools Plus routines. Furthermore,
 *	you can make the decision to use Pascal and/or C strings on a per-project
 *	basis, or you can set it once and apply those settings to all your projects.
 *
 *	This ToolsPlus.h header and the ToolsPlus.c source file both recognize two
 *	defines that describe how you want to use C strings when calling some Tools
 *	Plus routines:
 *
 *	  TOOLSPLUS_ALLOWS_CSTRINGS		When set to true, Tools Plus routines that
 *									have a string parameter optionally accept
 *									a C string in place of a Pascal string
 *
 *	  TOOLSPLUS_USES_ONLY_CSTRINGS	When set to true, Tools Plus routines that
 *									have a string parameter accept _only_ a C
 *									string (Pascal strings are not accepted)
 *
 *
 *	Using Pascal strings only		No changes required
 *	(in ALL T+ projects)
 *
 *	Using C and/or Pascal strings	(1)	In this file, un-comment the line defining
 *	(in ALL T+ projects)				  #define TOOLSPLUS_ALLOWS_CSTRINGS 1
 *									(2)	When you want to use a C string as a
 *										parameter in a Tools Plus routine, use the
 *										routine name in lower case letters.
 *										(e.g., use alertbox instead of AlertBox)
 *
 *	Using C strings only			(1)	In this file, un-comment the line defining
 *	(in ALL T+ projects)				  #define TOOLSPLUS_USES_ONLY_CSTRINGS 1
 *									(2)	Use Tools Plus routines as you normally do,
 *										except with C strings in place of Pascal
 *										strings.
 *
 *	Using Pascal strings only		No changes required
 *	(on a per-project basis)
 *
 *	Using C and/or Pascal strings	(1) Add the following line to your prefixes*
 *	(on a per-project basis)			  #define TOOLSPLUS_ALLOWS_CSTRINGS 1
 *									(2)	When you want to use a C string in a
 *										parameter in a Tools Plus routine, use the
 *										routine name in lower case letters.
 *										(e.g., use alertbox instead of AlertBox)
 *
 *	Using C strings only			(1)	Add the following line to your prefixes*
 *	(on a per-project basis)			  #define TOOLSPLUS_USES_ONLY_CSTRINGS 1
 *									(2)	Use Tools Plus routines as you normally do,
 *										except with C strings in place of Pascal
 *										strings.
 *
 *	*NOTE:	CodeWarrior uses a prefix file. Symantec's prefixes are entered using the
 *			development environment (Edit menu, Options, Prefix)
 */


#ifndef __ToolsPlus__
#define __ToolsPlus__

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=mac68k
#endif

											/* C / PASCAL STRINGS:							*/
											/*	 Un-comment *ONE* of the following lines if	*/
											/*	 you want to use C strings in ALL projects	*/
											/*	 you create with Tools Plus				*/
//#define TOOLSPLUS_USES_ONLY_CSTRINGS 1	/* <-- C strings only in Tools Plus parameters	*/
//#define TOOLSPLUS_ALLOWS_CSTRINGS	   1	/* <-- C or Pascal strings in the same app		*/


#ifndef TOOLSPLUS_USES_ONLY_CSTRINGS
#define	TOOLSPLUS_USES_ONLY_CSTRINGS 0
#endif

#ifndef TOOLSPLUS_ALLOWS_CSTRINGS
#define TOOLSPLUS_ALLOWS_CSTRINGS TOOLSPLUS_USES_ONLY_CSTRINGS
#endif




											/* INITIALIZATION:								*/
#define  initIgnoreColor		 0x00000000	/*	 Don't use Color QuickDraw					*/
#define  initUseColor			 0x00000001	/*	 Use Color QD if available					*/
#define  initUseTEScrap			 0x00000002	/*	 Use TextEdit scrap							*/
#define  initIgnoreTEScrap		 0x00000000	/*	 Don't use TextEdit scrap					*/
#define  initDontUnloadDeskScrap 0x00000004	/*	 Don't unload desk scrap					*/
#define  initUnloadDeskScrap	 0x00000008	/*	 Unload desk scrap to disk					*/
#define  initTEStr255Buffer		 255		/*	 TextEdit & Undo buffer: 255 chars			*/
#define  initTE32KBuffer		 32767		/*	 						 32K chars			*/

											/* POLLING:										*/
#define  doNothing			0				/*	 No event									*/
#define  doChgWindow		1				/*	 User clicked in an inactive window			*/
#define  doRefresh			2				/*	 A window has to be refreshed				*/
#define  doGoAway			3				/*	 The close box was clicked					*/
#define  doButton			4				/*	 Button was clicked							*/
#define  doMenu				5				/*	 Menu was selected							*/
#define  doKeyDown			6				/*	 A keyboard key was pressed					*/
#define  doAutoKey			7				/*	 A keyboard key is auto-repeating			*/
#define  doKeyUp			8				/*	 A keyboard key was released				*/
#define  doClickField		9				/*	 Mouse clicked in inactive field			*/
#define  doScrollBar		10				/*	 Mouse clicked in a scroll bar				*/
#define  doListBox			11				/*	 Some sort of List Box activity				*/
#define  doClick			12				/*	 Mouse click/drag [1..3] 					*/
#define  doPopUpMenu		13				/*	 Pop-up menu was selected					*/
#define  doPictButton		14				/*	 Picture button activity					*/
#define  doClickControl		101				/*	 Mouse clicked in a custom control			*/
#define  doManualEvent		102				/*	 Manually processed events					*/
#define  doMoveWindow		103				/*	 A window was dragged by user				*/
#define  doGrowWindow		104				/*	 A window was "grown" by user				*/
#define  doClickDesk		105				/*	 Mouse clicked in the desk top				*/
#define  doZoomWindow		106				/*	 Zoom box was clicked by user				*/
#define  doSuspend			107				/*	 Appl. suspended (in background)			*/
#define  doResume			108				/*	 Appl. resumed (now active appl.)			*/
#define  doChgInField		109				/*	 Editing field contents was changed			*/
#define  doPreRefresh		110				/*	 Refresh window before T+ objects			*/
#define  doActivate			111				/*	 Window was activated						*/
#define  doDeactivate		112				/*	 Window was deactivated						*/
#define  doMoveCursor		113				/*	 Cursor has entered a new Cursor Zone		*/
#define  inUpButton			20				/*	 Parts of Scroll Bar: Up button				*/
#define  inDownButton		21				/*						  Down button			*/
#define  inPageUp			22				/*						  Page Up area			*/
#define  inPageDown			23				/*						  Page Down area		*/
#define  inThumb			129				/*						  Thumb					*/
#define  inClick1			1				/*	 Clicks: Mouse single-click completed		*/
#define  inClick2			2				/*			 Mouse double-click completed		*/
#define  inClick3			3				/*			 Mouse triple-click completed		*/
#define  inClick1Drag		-1				/*			 Mouse single-click, still dragging	*/
#define  inClick2Drag		-2				/*			 Mouse double-click, still dragging	*/
#define  inClick3Drag		-3				/*			 Mouse triple-click, still dragging	*/
#define  EnterKey			(char)0x03		/*	 Keys:	Key characters (ASCII) for the most	*/
#define  BackSpaceKey		(char)0x08		/*			  commonly encountered keys.  In	*/
#define  DeleteKey			BackSpaceKey	/*			  some cases, several keys produce	*/
#define  TabKey				(char)0x09		/*			  the same ASCII character.  They	*/
#define  ReturnKey			(char)0x0D		/*			  may be differentiated by using	*/
#define  EscClearKey		(char)0x1B		/* (0x1B)	  the key code, as indicated below.	*/
#define  LeftArrowKey		(char)0x1C		/*			  Some keys are available only on	*/
#define  RightArrowKey		(char)0x1D		/* 			  an "extended" keyboard.			*/
#define  UpArrowKey			(char)0x1E		/*			  									*/
#define  DownArrowKey		(char)0x1F		/*												*/
#define  HelpKey			(char)0x05		/*												*/
#define  HomeKey			(char)0x01		/*												*/
#define  DeleteFwdKey		(char)0x7F		/*												*/
#define  EndKey				(char)0x04		/*												*/
#define  PageUpKey			(char)0x0B		/*												*/
#define  PageDownKey		(char)0x0C		/*												*/
#define  FKey				(char)0x10		/* (0x10)	Function keys "F1" to "F15"			*/
#define  EscKeyCode			0x35			/* (0x1B)	KEY CODES used to differentiate		*/
#define  ClearKeyCode		0x47			/* (0x1B)	  between keys which produce the	*/
#define  F1KeyCode			0x7A			/* (0x10)	  same key characters.				*/
#define  F2KeyCode			0x78			/*												*/
#define  F3KeyCode			0x63			/*												*/
#define  F4KeyCode			0x76			/*												*/
#define  F5KeyCode			0x60			/*												*/
#define  F6KeyCode			0x61			/*												*/
#define  F7KeyCode			0x62			/*												*/
#define  F8KeyCode			0x64			/*												*/
#define  F9KeyCode			0x65			/*												*/
#define  F10KeyCode			0x6D			/*												*/
#define  F11KeyCode			0x67			/*												*/
#define  F12KeyCode			0x6F			/*												*/
#define  F13KeyCode			0x69			/*												*/
#define  F14KeyCode			0x6B			/*												*/
#define  F15KeyCode			0x71			/*												*/

											/* WINDOWS:										*/
#define  GoAway				true			/*	 No "close box"								*/
#define  NoGoAway			false			/*	 Window has a "close box"					*/
#define  Modal				true			/*	 Window is "modal"							*/
#define  NotModal			false			/*	 Window is not "modal						*/
#define  movableBoxProc		5				/*	 Movable modal dialog ProcID				*/
											/*	 (Added to the procID)						*/
#define  ZoomBox			8				/*		Zoom box								*/
#define  wCenter			0x00010000		/*		Auto-centering							*/
#define  wTile				0x00020000		/*		Auto-tiling								*/
#define  wRefresh			0x00040000		/*		Forced refresh							*/
#define  wNoOffScreen		0x00080000		/*		Prevent from being all off-screen		*/
#define  wAllOnScreen		0x00100000		/*		Entire window must be on screen			*/
#define  wNoZoomLines		0x01000000		/*		Suppress "zoom lines" when zooming		*/
#define  wHidden			0x02000000		/*		Window is opened hidden					*/
#define  wPalette			0x80000000		/*		Palette behavior (add to procID)		*/
											/*	 (Alternate [custom] procIDs)				*/
#define  ordPaletteProc		32000			/*		Window that looks like Palette			*/
#define  paletteProc		32000 + wPalette/*		T+s Floating Palette window			*/
#define  altPaletteProc		32002 + wPalette/*		T+s palette with drag bar on left		*/
											/*	 (Add to modal window procID, Sys 7+)		*/
#define  wAllowEditMenu		0x40000000		/*		Allow access to Edit menu only			*/
#define  wAllowMenus		0x20000000		/*		Allow access to all menus				*/
#define  wDimEditMenu		0x10000000		/*		Aisable Edit menu's items				*/
#define  wNoKind			0				/*	 Kinds of Windows:	Not open				*/
#define  wToolBarKind		1				/*						Tool Bar				*/
#define  wFloatingKind		2				/*						Floating Palette		*/
#define  wStandardKind		3				/*						Standard Window			*/
#define  wAnimateMove		0x01			/*	Moving Windows:	Animate w/Zoom Lines	*/
#define  wOffsetForToolBar	0x02			/*						Offset co-ords for TB	*/
#define  wShow				true			/*		Hiding Windows:	Display (unhide)		*/
#define  wHide				false			/*						Hide window				*/

											/* TOOL BAR:									*/
#define  tbShiftWindows		0x00000001		/*	 Shift windows when TB opens				*/
#define  tbOffsetNewWindows	0x00000002		/*	 Offset new windows as they are opened (if	*/
											/*		Tool Bar is open).						*/

											/* MENUS:										*/
#define  mFileMenu			 1				/*	 File menu number							*/
#define  mEditMenu			 2				/*	 Edit menu number							*/
#define  mAppleMenu			-1				/*	 Apple menu number							*/
#define  mHelpMenu			-2				/*	 Help menu number (System 7.0 or higher)	*/
#define  mApplicationsMenu	-3				/*	 Applications menu num. (Sys 7.0 or higher)	*/
#if TOOLSPLUS_USES_ONLY_CSTRINGS			/*	 Dividing line								*/
 #define mDividingLine		"-"				/*		(as a C string)							*/
#else										/*			or									*/
 #define mDividingLine		"\p-"			/*	 	(as a Pascal string)					*/
#endif										/*												*/
#define  AppleChar			(char)0x14		/*	 Apple character							*/
#define  CheckChar			(char)0x12		/*	 Check Mark character						*/
#define  DiamondChar		(char)0x13		/*	 Diamond character							*/
#define  DotChar			(char)0xA5		/*	 Dot (or bullet) character					*/
#define  NoChar				(char)0x00		/*	 no character								*/

											/* BUTTONS:										*/
#define  bUseWFont			0x00000008		/*	 Use parent window's font					*/
#define  bDefault			0x00010000		/*	 Default for the window					*/
#define  bCmdKey			0x00020000		/*	 Button is selectable via command key		*/
#define  bColorButton		0x00080000		/*	 Use color settings for this button			*/
#define  bHidden			0x00100000		/*	 Create a hidden button						*/
#define  bAutoMoveSize		0x00200000		/*	 Auto-move/size as window's size changes	*/
#define  selected			true			/*	 Button is selected (ie: checked)			*/
#define  notSelected		false			/*	 Button is not selected						*/
											/*	 For non-standard custom CDEFs only:		*/
#define  bCDEFPushButton	0x80000000		/*		Control is a push button				*/
#define  bCDEFRadioButton	0x40000000		/*		Control is a radio button				*/
#define  bCDEFCheckBox		0x20000000		/*		Control is a check box					*/

											/* SCROLL BARS:									*/
#define  scrlLeftEdge		-32768			/*	 Left edge of document						*/
#define  scrlTopEdge		-32768			/*	 Top edge of document						*/
#define  scrlRightEdge		32767			/*	 Right edge of document						*/
#define  scrlBottomEdge		32767			/*	 Bottom edge of document					*/
#define  scrlStandard		0x00000010		/*	 Standard scroll bar (default)				*/
#define  scrlLiveScroll		0x00010000		/*	 Live scrolling when dragging thumb			*/
#define  scrlValueLimit		0x00020000		/*	 Value is limited by minimum/maximum limit	*/
#define  scrlNoObscure		0x00040000		/*	 Don't obscure scroll bar on inactive window*/
#define  scrlColorScrollBar	0x00080000		/*	 Use color settings for this scroll bar		*/
#define  scrlHidden			0x00100000		/*	 Create a hidden scroll bar					*/
#define  scrlAutoMoveSize	0x00200000		/*	 Auto-resize as window's size changes		*/
											/* LIST BOXES:									*/
											/*	Standard Apple constants for backwards		*/
											/*	compatibility.  Don't mix with T+ constants:*/
#define  lUseSense			4				/*		Shift senses state of initial line		*/
#define  lNoExtend			16				/*		Shift won't extend selection			*/
#define  lNoDisjoint		32				/*		Click deselects previsous selections	*/
#define  lExtendDrag		64				/*		Drag extends without shift key			*/
#define  lOnlyOne			-128			/*		Prevent multiple selections				*/
											/*	Tools Plus List Box constants:				*/
#define  listDefault		0x00000000		/*		Default list box						*/
#define  listNoFrame		0x00040000		/*		Don't draw frame around the list box	*/
#define  listColorList		0x00080000		/*		Use color settings for this list box	*/
#define  listHidden			0x00100000		/*		Create a hidden list box				*/
#define  listAutoMoveSize	0x00200000		/*		Auto-move/size as window's size changes	*/
#define  listUseSense		0x00400000		/*		Shift senses state of initial line		*/
#define  listNoExtend		0x00800000		/*		Shift won't extend selection			*/
#define  listNoDisjoint		0x01000000		/*		Click deselects previsous selections	*/
#define  listExtendDrag		0x02000000		/*		Drag extends without shift key			*/
#define  listOnlyOne		0x04000000		/*		Prevent multiple selections				*/

											/* BUTTONS, MENUS, SCROLL BARS & ICONS:			*/
#define  enabled			true			/*	 Object is enabled (active)					*/
#define  disabled			false			/*	 Object is disabled (dim, inactive)			*/

											/* EDIT FIELDS:									*/
#define  teAllowCR			0x00000100		/*	 Allow Carriage Return in text				*/
#define  teNoCR				0x00000000		/*	 Disallow Carriage Return in text			*/
#define  teBox				0x00000000		/*	 Draw box around field						*/
#define  teNoBox			0x00000200		/*	 Don't draw box around field				*/
#define  teLengthLimit		0x00000400		/*	 Limit typing to field's length				*/
#define  teResizeHdl		0x00000800		/*	 Resize text handle to save RAM				*/
#define  teFilter			0x00001000		/*	 Use current field filter					*/
#define  teCstring			0x00002000		/*	 C string text format (32K max)				*/
#define  teDisabled			0x00004000		/*	 Field is disabled							*/
#define  teHidden			0x00008000		/*	 Create a hidden field						*/
											/*	 Default selection on activation:			*/
#define  teTabSelectEnd		0x00010000		/*	 	Insertion point at end					*/
#define  teTabSelectStart	0x00020000		/*	 	Insertion point at start				*/
#define  teTabSelectAll		0x00000000		/*	 	Select all text							*/
#define  teBuffered			0x00040000		/*	 Accelerate large fld with buffer			*/
#define  teAutoMoveSize		0x00080000		/*	 Auto-resize as window's size changes		*/
#define  teNoResetOnDeactivate 0x00100000	/*	 Retain scrolling on deactivate				*/
#define  teLiveScroll		0x00200000		/*	 Live scrolling using scroll bars			*/
#define  teVScroll			0x00400000		/*	 Field has a vertical scroll bar			*/
											/* Vert Scroll:	Bring scroll bar's top down by	*/
#define  teVScrollDown15	0x01000000		/*		15 pixels								*/
#define  teVScrollDown30	0x02000000		/*		30 pixels								*/
#define  teVScrollDown45	0x03000000		/*		45 pixels								*/
#define  teVScrollDown60	0x04000000		/*		60 pixels								*/
#define  teVScrollDown75	0x05000000		/*		75 pixels								*/
#define  teVScrollDown90	0x06000000		/*		90 pixels								*/
#define  teVScrollDown105	0x07000000		/*		105 pixels								*/
#define  teVScrollDown120	0x08000000		/*		120 pixels								*/
#define  teVScrollDown135	0x09000000		/*		135 pixels								*/
#define  teVScrollDown150	0x0A000000		/*		150 pixels								*/
#define  teVScrollDown165	0x0B000000		/*		165 pixels								*/
#define  teVScrollDown180	0x0C000000		/*		180 pixels								*/
#define  teVScrollDown195	0x0D000000		/*		195 pixels								*/
#define  teVScrollDown210	0x0E000000		/*		210 pixels								*/
#define  teVScrollDown225	0x0F000000		/*		225 pixels								*/
											/* Hor. Scroll:	Bring scr bar's left side right*/
#define  teHScrollRight15	0x10000000		/*		15 pixels								*/
#define  teHScrollRight30	0x20000000		/*		30 pixels								*/
#define  teHScrollRight45	0x30000000		/*		45 pixels								*/
#define  teHScrollRight60	0x40000000		/*		60 pixels								*/
#define  teHScrollRight75	0x50000000		/*		75 pixels								*/
#define  teHScrollRight90	0x60000000		/*		90 pixels								*/
#define  teHScrollRight105	0x70000000		/*		105 pixels								*/
#define  teHScrollRight120	0x80000000		/*		120 pixels								*/
#define  teHScrollRight135	0x90000000		/*		135 pixels								*/
#define  teHScrollRight150	0xA0000000		/*		150 pixels								*/
#define  teHScrollRight165	0xB0000000		/*		165 pixels								*/
#define  teHScrollRight180	0xC0000000		/*		180 pixels								*/
#define  teHScrollRight195	0xD0000000		/*		195 pixels								*/
#define  teHScrollRight210	0xE0000000		/*		210 pixels								*/
#define  teHScrollRight225	0xF0000000		/*		225 pixels								*/
#define  teBoxNoCR		teBox + teNoCR		/*	  Box & CR:	Box around field, no CR allowed	*/
#define  teBoxCR		teBox + teAllowCR	/*				Box around field, CR allowed	*/
#define  teNoBoxNoCR	teNoBox + teNoCR	/*				No box, no CR allowed			*/
#define  teNoBoxCR		teNoBox + teAllowCR	/*				No box, CR allowed				*/
#define  teLeftEdge			-32768			/*     Co-ords:	Window's left edge				*/
#define  teTopEdge			-32768			/*				Window's top edge				*/
#define  teRightEdge		32767			/*				Window's right edge				*/
#define  teBottomEdge		32767			/*				Window's bottom edge			*/
#define  teJustLeft			0				/*	 Alignment:	Text is left aligned			*/
#define  teJustCenter		1				/*				Text is centered				*/
#define  teJustRight		-1				/*				Text is right aligned			*/
#define  teSelectStart		1				/*	 Selection: Beginning of text				*/
#define  teSelectEnd		2				/*				End of text						*/
#define  teSelectAll		3				/*				All text						*/
#define  teSelectDefault	0				/*				Default (as per field's spec)	*/

											/* TEXT DRAWING:								*/
#define  teWhiteBack		0x00000000		/*	 White background							*/
#define  teBackdrop			0x00000001		/*	 Draw on backdrop color						*/
#define  teColorBack		0x00000002		/*	 Color background							*/
#define  teNoBack			0x00000004		/*	 Transparent background						*/
#define  teBlackText		0x00000000		/*	 Black text									*/
#define  teColorText		0x00000010		/*	 Foreground colored text					*/
											/*			    Combinations					*/
#define  teBlackOnBackdrop	teBlackText + teBackdrop	/*	Black text on backdrop			*/
#define  teBlackOnWhite		teBlackText + teWhiteBack	/*	Black text on white				*/
#define  teBlackOnColor		teBlackText + teColorBack	/*	Black text on color				*/
#define  teBlackOnClear		teBlackText + teNoBack		/*	Black text, no background		*/
#define  teColorOnBackdrop	teColorText + teBackdrop	/*	Color text on backdrop			*/
#define  teColorOnWhite		teColorText + teWhiteBack	/*	Color text on white				*/
#define  teColorOnColor		teColorText + teColorBack	/*	Color text on color				*/
#define  teColorOnClear		teColorText + teNoBack		/*	Color text, no background		*/

											/* PASTE INTO FIELD:							*/
#define  teReplace			true			/*	 Replace field contents						*/
#define  teInsert			false			/*	 Insert text into field						*/

											/* DISABLED FIELDS:								*/
#define  teNeverDimBWText	 0x00000001		/*	 Never dim text (Black & White)				*/
#define  teNeverDimColorText 0x00000002		/*	 Never dim text (color)						*/
#define  teColSys6Text		 0x00000004		/*	 Colorize System 6 text						*/
#define  teNeverDimBWBox	 0x00000008		/*	 Never dim outline (Black & White)			*/
#define  teNeverDimColorBox	 0x00000010		/*	 Never dim outline (color)					*/
#define  teColSys6Box		 0x00000020		/*	 Colorize Sys 6 outline						*/
#define  teClickBeep		 0x00000040		/*	 Beep when disabled							*/
#define  teDfltDisabledLook	 0x00000000		/*	 Use default settings						*/

											/* FIELD FILTERS:								*/
#define  teIgnoreCase		0x00000001		/*	 Disable case sensing						*/
#define  teIgnoreDiac		0x00000002		/*	 Disable diacritical sensing				*/
#define  teShiftCaseUp		0x00000004		/*	 Shift chars to upper case					*/
#define  teShiftCaseDown	0x00000008		/*	 Shift chars to lower case					*/

											/* PICTURE BUTTONS:								*/
#define  picbutInstantEvent		0x80000000	/*	 Report event on mouse-down					*/
#define  picbutTrackWithHilite	0x40000000	/*	 Track using hiliting, like radio button	*/
#define  picbutLockSelected		0x20000000	/*	 Lock if selected (mouse can't deselect)	*/
#define  picbutSwitchSelected	0x10000000	/*	 Switch "selected" state if clicked			*/
#define  picbutRepeatEvents		0x08000000	/*	 Repeat event when button is held down		*/
#define  picbutAutoValueChg		0x04000000	/*	 Automatically change button's value		*/
#define  picbutScaleLinear		0x00000000	/*	 Rate of automatic value change			*/
#define  picbutScaleSlowAccel	0x01000000	/*	 	Linear, Slow Acceleration,				*/
#define  picbutScaleMedAccel	0x02000000	/*	 	Medium Acceleration, and				*/
#define  picbutScaleFastAccel	0x03000000	/*	 	Fast Acceleration.						*/
#define  picbutLinear			0			/*	 	Linear	(use in structure only)			*/
#define  picbutSlowAccel		1			/*	 	Slow	(use in structure only)			*/
#define  picbutMedAccel			2			/*	 	Medium	(use in structure only)			*/
#define  picbutFastAccel		3			/*	 	Fast	(use in structure only)			*/
#define  picbutValueWrap		0x00800000	/*	 Button's range of values "wrap" around		*/
#define  picbutLeftRightSplit	0x00400000	/*	 Left side reduces value, right increases	*/
#define  picbutTopBottomSplit	0x00200000	/*	 Top increases value, bottom reduces		*/
#define  picbutMultiStage		0x00100000	/*	 Button has multiple stages					*/
#define  picbutBigSICN3D		0x00080000	/*	 Create a larger SICN 3D button				*/
#define  picbutUsePICTS			0x00040000	/*	 Use PICTs instead of icons					*/
#define  picbutGray4use8		0x00020000	/*	 Use 8-bit color pict on 4-bit gray CRT		*/
#define  picbutHidden			0x00000200	/*	 Create a hidden picture button				*/
#define  picbutAutoMoveSize		0x00000001	/*	 Auto-resize as window's size changes		*/
											/*	 Selection Effects							*/
#define  picbutSelectDarken		   0x00010000/*		Darken image							*/
#define  picbutSelectDarkenSICN3D  0x00008000/*		Darken (and push in) a 3D SICN icon		*/
#define  picbutSelectLightenSICN3D 0x00004000/*		Lighten (and push in) a 3D SICN icon	*/
#define  picbutSelectPushedSICN3D  0x00002000/*		Same color (and push in) a 3D SICN icon	*/
#define  picbutSelectAltImage	   0x00000400/*		Use an alternate image					*/
											/*	 Disabling Effects							*/
#define  picbutDimUsingBlackLite 0x00000100	/*		Overlay Black color using Lt Gray pat.	*/
#define  picbutDimUsingWhiteLite 0x00000080	/*		Overlay White color using Lt Gray pat.	*/
#define  picbutDimUsingWhite	 0x00000040	/*		Overlay White color using Gray pat.		*/
#define  picbutDimLeaveBorder	 0x00000008	/*		Leave border when applying effect		*/
#define  picbutDimAltImage		 0x00000004	/*		Use an alternate image					*/
#define  picbutDimNoChange		 0x00000002	/*		Button looks the same when disabled		*/

											/* POP-UP MENUS:								*/
#define  popupHidden			0x00008000	/*	 Create a hidden pop-up menu				*/
#define  popupAutoMoveSize		0x00004000	/*	 Auto-resize as window's size changes		*/
#define  popupHasBackground		0x00000200	/*	 Pop-Up Menu is drawn over an image			*/
#define  popupNeverDimOutline	0x00000100	/*	 Never dim the control's outline			*/
#define  popupNeverDimSelection	0x00000080	/*	 Never dim the selected item's text			*/
#define  popupNeverDimTitle		0x00000040	/*	 Never dim the title						*/
#define  popupNoArrow			0x00000020	/*	 Is the "down arrow" hidden					*/
#define  popupMultiSelect		0x00000010	/*	 Allow multiple items to be selected		*/
#define  popupUseWFont			0x00000008	/*	 Use the window's font for the menu			*/
#define  popupIconTitle			0x00000004	/*	 Draw icon in the control's title			*/
#define  popupFixedTitle		0x00000002	/*	 Is fixed title displayed in the control	*/
#define  popupDefaultType		0x00000000	/*	 Default menu (sys font, 1 item, no icon)	*/

											/* PANELS:										*/
#define  panFillBack			0x00000001	/*	 Fill panel with background color			*/
#define  panOutlined			0x00000002	/*	 Always draw outline around panel			*/
#define  panOutline4bit			0x00000004	/*	 Draw outline on 4-bit monitors				*/
#define  panBlackBorder			0x00000008	/*	 Draw black border instead of gray			*/
#define  panBWGrayBorder		0x00000010	/*	 Draw gray pattern border on B&W monitor	*/
#define  panUseWFont			0x00000020	/*	 Draw title using window's font				*/
#define  panCustomColors		0x00000040	/*	 Use custom colors instead of standard ones	*/
#define  panColorText			0x00000080	/*	 Use foreground color for text				*/
#define  panColorBorder			0x00000100	/*	 Use foreground color for border			*/
#define  panColorBack			0x00000200	/*	 Use background color for background		*/
#define  panNoBackdrop			0x00000400	/*	 Use standard or custom background color	*/
											/*	 instead of window's backdrop color			*/
#define  panAutoDeselect		0x00000800	/*	 Auto-deselect buttons in this group		*/
											/*	 Title alignment:							*/
#define  panLeftTitle			0x00001000	/*		Left (default)							*/
#define  panRightTitle			0x00002000	/*		Right									*/
#define  panCenterTitle			0x00003000	/*		Center									*/
											/*	 Title's 3D styling:						*/
#define  panPlainTitle			0x00000000	/*		Plain title (no 3D effect)				*/
#define  panRaiseTitle			0x00010000	/*		Raised with light shadow				*/
#define  panRaiseTitleDark		0x00020000	/*		Raised with heavy shadow				*/
#define  panInsetTitle			0x00030000	/*		Inset with light shadow					*/
#define  panInsetTitleDark		0x00040000	/*		Inset with heavy shadow					*/
											/*	 Shadow styling:							*/
#define  panNoShadow			0x00000000	/*		No shadow (default)						*/
#define  panRaiseShadow			0x00080000	/*		Panel raises from window				*/
#define  panInsetShadow			0x00100000	/*		Panel sinks into window					*/
											/*	 Round-corner Width:						*/
#define  panRoundCorner1		0x01000000	/*		RoundRect oval size of 1 pixel			*/
#define  panRoundCorner2		0x02000000	/*		RoundRect oval size of 2 pixels			*/
#define  panRoundCorner3		0x03000000	/*		RoundRect oval size of 3 pixels			*/
#define  panRoundCorner4		0x04000000	/*		RoundRect oval size of 4 pixels			*/
#define  panRoundCorner5		0x05000000	/*		RoundRect oval size of 5 pixels			*/
#define  panRoundCorner6		0x06000000	/*		RoundRect oval size of 6 pixels			*/
#define  panRoundCorner7		0x07000000	/*		RoundRect oval size of 7 pixels			*/
#define  panRoundCorner8		0x08000000	/*		RoundRect oval size of 8 pixels			*/
#define  panRoundCorner9		0x09000000	/*		RoundRect oval size of 9 pixels			*/
#define  panRoundCorner10		0x0A000000	/*		RoundRect oval size of 10 pixels		*/
#define  panRoundCorner11		0x0B000000	/*		RoundRect oval size of 11 pixels		*/
#define  panRoundCorner12		0x0C000000	/*		RoundRect oval size of 12 pixels		*/
#define  panRoundCorner13		0x0D000000	/*		RoundRect oval size of 13 pixels		*/
#define  panRoundCorner14		0x0E000000	/*		RoundRect oval size of 14 pixels		*/
#define  panRoundCorner15		0x0F000000	/*		RoundRect oval size of 15 pixels		*/
#define  panRoundCorner16		0x10000000	/*		RoundRect oval size of 16 pixels		*/
#define  panRoundCorner17		0x11000000	/*		RoundRect oval size of 17 pixels		*/
#define  panRoundCorner18		0x12000000	/*		RoundRect oval size of 18 pixels		*/
#define  panRoundCorner19		0x13000000	/*		RoundRect oval size of 19 pixels		*/
#define  panRoundCorner20		0x14000000	/*		RoundRect oval size of 20 pixels		*/
#define  panRoundCorner21		0x15000000	/*		RoundRect oval size of 21 pixels		*/
#define  panRoundCorner22		0x16000000	/*		RoundRect oval size of 22 pixels		*/
#define  panRoundCorner23		0x17000000	/*		RoundRect oval size of 23 pixels		*/
#define  panRoundCorner24		0x18000000	/*		RoundRect oval size of 24 pixels		*/
#define  panRoundCorner25		0x19000000	/*		RoundRect oval size of 25 pixels		*/
#define  panRoundCorner26		0x1A000000	/*		RoundRect oval size of 26 pixels		*/
#define  panRoundCorner27		0x1B000000	/*		RoundRect oval size of 27 pixels		*/
#define  panRoundCorner28		0x1C000000	/*		RoundRect oval size of 28 pixels		*/
#define  panRoundCorner29		0x1D000000	/*		RoundRect oval size of 29 pixels		*/
#define  panRoundCorner30		0x1E000000	/*		RoundRect oval size of 30 pixels		*/
#define  panRoundCorner31		0x1F000000	/*		RoundRect oval size of 31 pixels		*/
#define  panAutoMoveSize		0x40000000	/*		Auto-move/size as window's size changes	*/
#define  panHidden				0x80000000	/*	 Panel is hidden							*/
											/*	 Popular combinations:						*/
											/*		Standard group box						*/
#define  panGroupBox		panLeftTitle + panBlackBorder + panNoShadow + panAutoDeselect
											/*		3D group box							*/
#define  pan3DGroupBox		panLeftTitle + panInsetShadow + panRaiseTitle + panAutoDeselect

											/* CURSORS:										*/
#define  arrowCursor		0				/*	 Standard arrow cursor						*/

											/* ALERTS:										*/
#define  OkAltBut			1				/*	 OK				(Buttons)					*/
#define  CanAltBut			2				/*	 Cancel										*/
#define  YesAltBut			3				/*	 Yes										*/
#define  NoAltBut			4				/*	 No											*/
#define  ContAltBut			5				/*	 Continue									*/
#define  SkipAltBut			6				/*	 Skip										*/
#define  QuitAltBut			7				/*	 Quit										*/
#define  NoButtonAlert		0				/*	 No buttons		(Combinations)				*/
#define  OkAlert			11100			/*	 OK (default)								*/
#define  CanAlert			11200			/*	 Cancel (default)							*/
#define  OkCanAlert			22210			/*	 OK (default) + Cancel						*/
#define  CanOkAlert			21210			/*	 OK + Cancel (default)						*/
#define  YesNoAlert			22430			/*	 Yes (default) + No							*/
#define  NoYesAlert			21430			/*	 Yes + No (default) 						*/
#define  YesNoCanAlert		33243			/*	 Yes (default) + No + Cancel				*/
#define  NoYesCanAlert		32243			/*	 Yes + No (default) + Cancel				*/

											/* NOTIFICATION:								*/
#define  nmSysBeep			-1				/*	 Use System Error sound						*/
#define  nmSilentNote		0				/*	 Silent notification						*/
#if TOOLSPLUS_USES_ONLY_CSTRINGS			/*	 Use default message						*/
 #define nmDefaultMsg		" "				/*		(as a C string)							*/
#else										/*			or									*/
 #define nmDefaultMsg		"\p "			/*	 	(as a Pascal string)					*/
#endif										/*												*/
#if TOOLSPLUS_USES_ONLY_CSTRINGS			/*	 Don't display an alert						*/
 #define nmNoMsg			""				/*		(as a C string)							*/
#else										/*			or									*/
 #define nmNoMsg			"\p"			/*	 	(as a Pascal string)					*/
#endif										/*												*/
#define  nmResetWhenDone	true			/*	 Reset to defaults after used				*/
#define  nmKeepSettings		false			/*	 Keep settings after used					*/

											/* ICONS:										*/
#define  NoIcon				-32768			/*	 No icon used								*/
#define  stopIcon			0				/*	 Stop icon									*/
#define  noteIcon			1				/*	 Note icon									*/
#define  cautionIcon		2				/*	 Caution icon								*/
											/*	 Disabled icons' default appearance		*/
#define  DfltIconDimBlackLtPat	0x00000001	/*		Overlay Black color w/ Lt Gray pattern	*/
#define  DfltIconDimWhiteLtPat	0x00000002	/*		Overlay White color w/ Lt Gray pattern	*/
#define  DfltIconDimWhitePat	0x00000004	/*		Overlay White color w/ Gray pattern		*/
#define  DfltIconLeaveBorder	0x00000020	/*	 Leave border when selected or disabled		*/
#define  DfltIconUpdateNow		0x00008000	/*	 Update all windows with changes			*/

											/* PICTs:										*/
#define  pictScale1PICT			0x00000000	/*	 Scale PICT to specified rectangle			*/
#define  pictUsePictRect		0x00000001	/*	 Use picture's rectangle					*/
#define  pictClipToRect			0x00000002	/*	 Clip picture to rectangle					*/
#define  pictOnBackdrop			0x00000004	/*	 Clear w/backdrop col. before drawing		*/
#define  pictOnWhite			0x00000008	/*	 Clear w/white before drawing				*/
#define  pictOnColor			0x00000010	/*	 Clear w/backgnd col. before drawing		*/
#define  pictMultiPICT			0x00000020	/*	 Use different PICT/monitor setting			*/
#define  pictBWplus				0x00000040	/*	 Use better pict if B&W not available		*/
#define  pictGray4plus			0x00000080	/*	 Use better pict if 4-bit gray n/a			*/
#define  pictColor4plus			0x00000100	/*	 Use better pict if 4-bit color n/a			*/
#define  pictGray8plus			0x00000200	/*	 Use better pict if 8-bit gray n/a			*/
#define  pictColor8plus			0x00000400	/*	 Use better pict if 8-bit color n/a			*/

											/* BITMAPS:										*/
#define  bitmapBW					0		/*	 Create a 1-bit B&W bitmap					*/
#define  bitmapFromWindow			1		/*	 PixMap based on window's max pixel depth	*/
#define  bitmapFromGDevice			2		/*	 PixMap based on specified GDevice			*/
#define  bitmapFromCurrentGDevice	3		/*	 PixMap based on current GDevice			*/
#define  bitmapFromMaxGDevice		4		/*	 PixMap based on maximum GDevice			*/

											/* MISCELLANEOUS:								*/
#define  on					true			/*	 Synonym for "true"							*/
#define  off				false			/*	 Synonym for "false"						*/
#define  none				0				/*	 Used primarily for polling					*/
#define  maxNullTime		0x7FFFFFFF		/*	 Infinite time between doNothing events		*/

											/* ZOOM LINES:									*/
#define  ZoomAcross			0				/*	 Transitional								*/
#define  ZoomIn				-1				/*	 Zoom inward (further away)					*/
#define  ZoomOut			1				/*	 Zoom outward (nearer)						*/





/* - - - - - - These record "types" are used for information transfer between - - - - - - -	*/
/*		 				your application and Tools Plus libraries.							*/

/*= Polling record's "event modifiers" info*/
  union TPModifiersRec {					/*This variable record contains an event's		*/
											/*	"modifiers" in 2 formats					*/
											/*	 Macintosh Event:							*/
		short Num;							/*		short (bit operations required)			*/
		struct {							/*	 Modifier short parsed into components:	*/
			unsigned short bit15 :1;		/*		(reserved bit)							*/
			unsigned short bit14 :1;		/*		(reserved bit)							*/
			unsigned short bit13 :1;		/*		(reserved bit)							*/
			unsigned short ControlKey :1;	/*		Control key was down at event (=1)		*/
			unsigned short OptionKey :1;	/*		Option key was down at event (=1)		*/
			unsigned short CapsLock :1;		/*		Caps Lock was down at event (=1)		*/
			unsigned short ShiftKey :1;		/*		Shift key was down at event (=1)		*/
			unsigned short CmdKey :1;		/*		Command key was down at event (=1)		*/
			unsigned short MouseUp :1;		/*		Mouse button was UP at event (=1)		*/
			unsigned short bit6 :1;			/*		(reserved bit)							*/
			unsigned short bit5 :1;			/*		(reserved bit)							*/
			unsigned short bit4 :1;			/*		(reserved bit)							*/
			unsigned short bit3 :1;			/*		(reserved bit)							*/
			unsigned short bit2 :1;			/*		(reserved bit)							*/
			unsigned short bit1 :1;			/*		(reserved bit)							*/
			unsigned short bit0 :1;			/*		(reserved bit)							*/
		} Bits;								/*												*/
	};
	typedef union TPModifiersRec TPModifiersRec;
/*= Polling record's "button" info*/
  	struct TPPollButtonRec {
		short Num;							/*Button number									*/
		Boolean DoubleClick;				/*Did a double-click occur?						*/
	};
	typedef struct TPPollButtonRec TPPollButtonRec;
/*= Polling record's "scroll bar" info*/
  	struct TPPollScrollBarRec {
		short Num;							/*Scroll bar number								*/
		short Part;							/*Scroll bar's part								*/
	};
	typedef struct TPPollScrollBarRec TPPollScrollBarRec;
/*= Polling record's "list box" info*/
	struct TPPollListBoxRec {
		short Num;							/*List box number								*/
		Boolean DoubleClick;				/*Did a double-click occur?						*/
	};
	typedef struct TPPollListBoxRec TPPollListBoxRec;
/*= Polling record's "menu" info*/
	struct TPPollMenuRec {
		short Num;							/*Menu number									*/
		short Item;							/*Menu item number								*/
	};
	typedef struct TPPollMenuRec TPPollMenuRec;
/*= Polling record's "key-stroke" info*/
	struct TPPollKeyRec {
		short Code;							/*Logical key number of the typed key			*/
		char Chr;							/*ASCII character generated by typed key		*/
		Byte Unused;						/* (reserved byte)								*/				
	};
	typedef struct TPPollKeyRec TPPollKeyRec;
/*= Polling record's "mouse location and time" info for mouse-down and mouse-up events*/
	struct TPPollMousePointRec {
		Point Where;						/*Event location in local co-ordinates			*/
		long When;							/*Event time in clock ticks from boot (1/60 sec)*/
		TPModifiersRec Modifiers;			/*Event modifiers								*/
	};
	typedef struct TPPollMousePointRec TPPollMousePointRec;
/*= Polling record's "mouse click/drag" info*/
	struct TPPollMouseRec {
		short What;							/*What type of mouse event? (click or drag)		*/
		TPPollMousePointRec Down[3];		/*Where & when did the mouse-down occur			*/
		TPPollMousePointRec Up[3];			/*Where & when did the mouse-up occur			*/
		Point Where;						/*Current mouse location in local co-ordinates	*/
	};
	typedef struct TPPollMouseRec TPPollMouseRec;
/*= POLLING record for Tools Plus*/
	struct TPPollRecord {					/*Tools Plus Polling record					*/
		short What;							/*What type of event has occurred?				*/
		short Window;						/*Window number of the event					*/
		TPPollButtonRec Button;				/*Button number/double-click status				*/
		TPPollScrollBarRec ScrollBar;		/*Scroll bar number/scroll bar part				*/
		short Field;						/*Field number of event							*/
		TPPollListBoxRec ListBox;			/*List box number/double-click status			*/
		TPPollMenuRec Menu;					/*Menu number/menu item of an event				*/
		TPPollKeyRec Key;					/*Logical key number & character of typed key	*/
		TPPollMouseRec Mouse;				/*Click/drag info: [1..3] where & when			*/
		TPModifiersRec Modifiers;			/*Modifier flags								*/
		EventRecord Event;					/*Macintosh Toolbox Event (raw)					*/
	};
	typedef struct TPPollRecord TPPollRecord;
	typedef TPPollRecord *TPPollPointer;	/*Pointer to a Polling record					*/


/*= WINDOW status information*/
	struct TPWindowStatus {
		short Kind;							/*Window kind: Tool Bar, Palette, or Standard	*/
		Boolean Open;						/*Is the window open							*/
		Boolean Visible;					/*Is this window visible (not hidden)			*/
		Boolean Active;						/*Is this window active							*/
		Boolean Front;						/*Is this the frontmost Tools Plus window		*/
		Boolean Current;					/*Is this the current window					*/
		Boolean WorkWindow;					/*Is this the work window						*/
		Boolean EditFieldWindow;			/*Does this window have app's active field		*/
		short ActiveField;					/*Window's active field number					*/
		Rect StrucRect;						/*Structure rect (global). Incl border&title bar*/
		Rect ContRect;						/*Content rect (global).  Working area only.	*/
	};
	typedef struct TPWindowStatus TPWindowStatus;


/*= Color Pen information*/
	struct ColorPenState {					/*Color equivalent for a "PenState" record.		*/
		PenState PenState;					/*	This record also stores additional values	*/
		RGBColor ForegroundColor;			/*	for the window's foreground and background	*/
		RGBColor BackgroundColor;			/*	colors.										*/
	};
	typedef struct ColorPenState ColorPenState;


/*= Picture Button Appearance & Behavior Specification (or you can use constants instead)	*/
	union TPPictButtonSpec {						/*Picture Button's appearance and		*/
													/*	behavior specs in 2 formats		*/
		struct{										/*  Parsed into components:			*/
			unsigned short InstantEvent: 1;			/*		Report event on mouse-down		*/
			unsigned short TrackWithHilite: 1;		/*		Track using hiliting (like a	*/
													/*			radio button)				*/
			unsigned short LockSelected: 1;			/*		Lock if selected (mouse can't	*/
													/*			deselect)					*/
			unsigned short SwitchSelected: 1;		/*		Switch "select" state if clicked*/
			unsigned short RepeatEvents: 1;			/*		Repeat event when button is held*/
			unsigned short AutoValueChg: 1;			/*		Automatically chg button's value*/
			unsigned short AutoValueScaling: 3;		/*		Rate of chg for button's value	*/
			unsigned short ValueWrap: 1;			/*		Button's range of values "wrap"	*/
													/*			around.						*/
			unsigned short LeftRightSplit: 1;		/*		Left side reduces value, right	*/
													/*			increases.					*/
			unsigned short TopBottomSplit: 1;		/*		Top increases value, bottom		*/
													/*			reduces.					*/
			unsigned short MultiStage: 1;			/*		Button has multiple stages		*/
			unsigned short BigSICN3D: 1;			/*		Create a larger SICN 3D button	*/
			unsigned short UsePICTS: 1;				/*		Use PICTs instead of icons		*/
			unsigned short Gray4use8: 1;			/*		Use 8-bit color pict on 4-bit	*/
													/*			gray monitor.				*/
													/*	Selection Effects					*/
			unsigned short SelectDarken: 1;			/*		Darken image					*/
			unsigned short SelectDarkenSICN3D: 1;	/*		Darken (+push in) a 3D SICN icon*/
			unsigned short SelectLightenSICN3D: 1;	/*		Lighten (+push in) 3D SICN icon	*/
			unsigned short SelectPushedSICN3D: 1;	/*		Same color (+push) 3D SICN icon	*/
			unsigned short bit12: 1;				/*			(reserved bit)				*/
			unsigned short bit11: 1;				/*			(reserved bit)				*/
			unsigned short SelectAltImage: 1;		/*		Use an alternate image			*/
			unsigned short Hidden: 1;				/*	 Create a hidden picture button		*/
													/*   Disabling Effects					*/
			unsigned short DimUsingBlackLite: 1;	/*		Overlay Black color, Lt Gray pat*/
			unsigned short DimUsingWhiteLite: 1;	/*		Overlay White color, Lt Gray pat*/
			unsigned short DimUsingWhite: 1;		/*		Overlay White color, Gray pat.	*/
			unsigned short bit5: 1;					/*			(reserved bit)				*/
			unsigned short bit4: 1;					/*			(reserved bit)				*/
			unsigned short DimLeaveBorder: 1;		/*		Leave border when effect applied*/
			unsigned short DimAltImage: 1;			/*		Use an alternate image			*/
			unsigned short DimNoChange: 1;			/*		Button looks same when disabled	*/
			unsigned short AutoMoveSize: 1;			/*	Auto-resize as window's size chg	*/
		} Bits;										/*										*/
		long Num;									/*  Long equivalent					*/
	};												/*										*/
	typedef union TPPictButtonSpec TPPictButtonSpec;


/*= Pop-Up Menu Appearance & Behavior Specification (or you can use constants instead)		*/
	union TPPopUpMenuSpec {							/*Pop-Up Menu's appearance and behavior	*/
													/*	specifications in 2 formats		*/
		struct{										/*  Parsed into components:			*/
			short bits31to16;						/*		(reserved bits)					*/
			unsigned short Hidden :1;				/*	 Create a hidden Pop-Up Menu		*/
			unsigned short AutoMoveSize :1;			/*	 Auto-resize as window's size chg	*/
			unsigned short bit13 :1;				/*		(reserved bit)					*/
			unsigned short bit12 :1;				/*		(reserved bit)					*/
			unsigned short bit11 :1;				/*		(reserved bit)					*/
			unsigned short bit10 :1;				/*		(reserved bit)					*/
			unsigned short HasBackground: 1;		/*	 Pop-Up Menu is drawn over an image	*/
			unsigned short NeverDimOutline :1;		/*	 Never dim the control's outline	*/
			unsigned short NeverDimSelectedItem: 1;	/*	 Never dim the selected item's text	*/
			unsigned short NeverDimTitle: 1;		/*	 Never dim the title				*/
			unsigned short NoArrow: 1;				/*	 Is the "down arrow" hidden			*/
			unsigned short MultipleSelections: 1;	/*	 Allow multiple items to be selected*/
			unsigned short UseWindowFont: 1;		/*	 Display using window's font		*/
			unsigned short IconInTitle: 1;			/*	 Draw icon in the control's title	*/
			unsigned short FixedTitle: 1;			/*	 Display fixed title in the control	*/
			unsigned short bit0 :1;					/*		(reserved bit)					*/
		} Bits;										/*										*/
		long Num;									/*  Long equivalent					*/
	};												/*										*/
	typedef union TPPopUpMenuSpec TPPopUpMenuSpec;


/*= Picture Drawing Appearance & Behavior Specification (or you can use constants instead)	*/
	union TPDrawPictSpec {							/*Picture drawing appearance & behavior	*/
													/*	specifications in 2 formats		*/
		struct{										/*  Parsed into components:			*/
			short bits31to16;						/*		(reserved bits)					*/
			unsigned short bit15 :1;				/*		(reserved bit)					*/
			unsigned short bit14 :1;				/*		(reserved bit)					*/
			unsigned short bit13 :1;				/*		(reserved bit)					*/
			unsigned short bit12 :1;				/*		(reserved bit)					*/
			unsigned short bit11 :1;				/*		(reserved bit)					*/
			unsigned short Color8plus :1;			/*	 Use better pict if 8-bit color n/a	*/
			unsigned short Gray8plus :1;			/*	 Use better pict if 8-bit gray n/a	*/
			unsigned short Color4plus :1;			/*	 Use better pict if 4-bit color n/a	*/
			unsigned short Gray4plus :1;			/*	 Use better pict if 4-bit gray n/a	*/
			unsigned short BWplus :1;				/*	 Use better pict if B&W not avail.	*/
			unsigned short MultiPICT :1;			/*	 Use different PICT/monitor setting	*/
			unsigned short DrawOnColor : 1;			/*	 Clear w/backgnd col. before drawing*/
			unsigned short DrawOnWhite : 1;			/*	 Clear w/white before drawing		*/
			unsigned short DrawOnBackdrop : 1;		/*	 Clear w/backdrop col before drawing*/
			unsigned short ClipToRect :1;			/*	 Clip picture to rectangle			*/
			unsigned short UsePictRect :1;			/*	 Use picture's rectangle			*/
		} Bits;										/*										*/
		long Num;									/*  Long equivalent					*/
	};												/*										*/
	typedef union TPDrawPictSpec TPDrawPictSpec;



#ifndef __CONDITIONALMACROS__					/*These types are declared purely for consistency between		*/
typedef ProcPtr UniversalProcPtr;				/*	header files for all C/C++ compilers, specifically the		*/
typedef UniversalProcPtr ControlActionUPP;		/*	universal interfaces used by PowerMacs.						*/
#endif											/*																*/




#ifdef __cplusplus
extern "C" {
#endif

/*======================================== I N I T I A L I Z A T I O N ========================================	*/
/*Initialize Tools Plus*/
	pascal Boolean InitToolsPlus (short MoreHandles,			/*Number of MoreMasters initializing cycles		*/
									short MaxWindows,			/*Maximum number of windows required			*/
									short TEBufferSize,			/*TextEdit buffer size (255 to 32767)			*/
									long InitSpec 				/*Initialization specifications					*/
									);							/* = Was initialization successful?				*/

/*Set the size of the stack in a 68K application*/
	pascal void Set68KStackSize (long bytes);					/*Stack's new size								*/

/*Change the stack's size*/
	pascal void ChangeStackSize (long bytes);					/*No. of bytes by whick stack size is changed	*/



/*=============================================== W I N D O W S ===============================================	*/
/*Open a window and make it current*/
	pascal void WindowOpen (short Window,						/*Window number									*/
									short left,					/*Window's co-ordinates (global)				*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom,				/*												*/
									const Str255 Title,			/*Window's title (if applicable)				*/
									long Spec,					/*Window specifications and procID				*/
									Boolean goAwayFlag,			/*Include Close Box?							*/
									Boolean modalFlag);			/*Is window modal?								*/

/*Open a window and make it current (co-ordinates specified as a "rect") */
	pascal void WindowOpenRect (short Window,					/*Window number									*/
									const Rect *Bounds,			/*Window's co-ordinates (global)				*/
									const Str255 Title,			/*Window's title (if applicable)				*/
									long Spec,					/*Window specifications and procID				*/
									Boolean goAwayFlag,			/*Include Close Box?							*/
									Boolean modalFlag);			/*Is window modal?								*/

/*Open the tool bar and make it current*/
	pascal void ToolBarOpen (short Window,						/*Window number									*/
									short Height,				/*Tool bar height								*/
									long Spec);					/*Appearance/behavior specifications			*/

/*Set the backdrop color for new windows*/
	pascal void BackdropColor (const RGBColor *Color);			/*Backdrop color for new windows				*/

/*Reset backdrop color for new windows to white*/
	pascal void NoBackdropColor(void);

/*Set a window's backdrop color*/
	pascal void SetBackdropColor (short Window,					/*Window number									*/
									const RGBColor *Color);		/*Backdrop color								*/

/*Close a window*/
	pascal void WindowClose (short Window);						/*Window number									*/

/*Change a window's size*/
	pascal void WindowSize (short Window,						/*Window number									*/
									short Width,				/*Window's new width							*/					
									short Height,				/*Window's new height							*/
									Boolean Update);			/*Force doRefresh event for newly exposed region*/

/*Move a window to the specified co-ordinates*/
	pascal void WindowMove (short Window,						/*Window number									*/
									short hGlobal,				/*Horizontal co-ordinates (global)				*/
									short vGlobal,				/*Vertical co-ordinates (global)				*/
									long Spec);					/*Behavior specifications						*/

/*Hide or show a window*/
	pascal void WindowDisplay (short Window,					/*Window number									*/
									Boolean Show);				/*Should the window be shown					*/

/*Make a specified window the "active" and "current" window*/
	pascal void ActivateWindow (short Window);					/*Window number									*/

/*Set a window's title*/
	pascal void WindowTitle (short Window,						/*Window number									*/
									const Str255 Title);		/*Window's title (if applicable)				*/

/*Set the current window's "growing" limits (ie: maximum/minimum size) */
	pascal void SetWindowSizeLimits (short minHoriz,			/*Window's size limits in pixels				*/
									short minVert,				/*												*/
									short maxHoriz,				/*												*/
									short MaxVert);				/*												*/

/*Set the current window's standard co-ordinates and user co-ordinates for "zooming"*/
	pascal void SetWindowZoom (const Rect *userRect,			/*User co-ordinates (global)					*/
									const Rect *stdRect);		/*Standard co-ordinates (global)				*/

/*Get the current window's user co-ordinates & standard co-ordinates for "zooming"*/
	pascal void GetWindowZoom (Rect *userRect, Rect *stdRect);	/*User & standard co-ordinates (global)			*/

/*Make a specified window "current", but do not activate it*/
	pascal void CurrentWindow (short Window);					/*Window number									*/

/*Make the "active" window the "current"*/
	pascal void CurrentWindowReset(void);

/*Get a window's status*/
	pascal void WindowStatus (short Window,						/*Window number									*/
									TPWindowStatus *Status);	/*Window's status record						*/

/*Refresh Tools Plus objects in a window*/
	pascal void RefreshToolsPlusInWindow (short Window);		/*Window number									*/

/*Get the active window number (last used window if Tool Bar and/or Floating Palettes are open)	*/
	pascal short ActiveWindowNumber(void);						/*Window number of active window				*/

/*Get the current window number*/
	pascal short CurrentWindowNumber(void);						/*Window number of current window				*/

/*Get the front most window number*/
	pascal short FirstWindowNumber(void);						/*Window number of front most window			*/

/*Get the Tool Bar's window number*/
	pascal short ToolBarNumber(void);							/*Tool Bar's window number						*/

/*Get the first floating Palette's window number*/
	pascal short FirstPaletteNumber(void);						/*Front most floating Palette's window number	*/

/*Get the first standard window's number (not Tool Bar or Floating Palette).*/
	pascal short FirstStdWindowNumber(void);					/*Front most standard window's number			*/

/*Get the working window number*/
	pascal short WorkWindowNumber(void);						/*Working window number							*/

/*Get the window number that contains the active editing field*/
	pascal short EditFldWindowNumber(void);						/*Window number containing active editing field	*/

/*Determine if a window is open*/
	pascal Boolean WindowIsOpen (short Window					/*Window number									*/
									);							/* = Is the window open?						*/

/*Determine if a window is visible (open and not hidden)*/
	pascal Boolean WindowIsVisible (short Window				/*Window number									*/
									);							/* = Is the window visible?						*/

/*Determine if a window is active*/
	pascal Boolean WindowIsActive (short Window					/*Window number									*/
									);							/* = Is the window active?						*/

/*Determine the type of window*/
	pascal short WindowKind (short Window						/*Window number									*/
									);							/* = Kind of window								*/

/*Get a window's "window pointer"*/
	pascal WindowPtr WindowPointer (short Window				/*Window number									*/
									); 							/* = Window's pointer							*/

/*Automatically resize subsequently created objects as their window's size changes*/
	pascal void AutoMoveSize (Boolean left,						/*Object's left side tracks window's right edge	*/
									Boolean top,				/*Object's top tracks window's bottom edge		*/
									Boolean right,				/*Object's right side tracks window's right edge*/
									Boolean bottom);			/*Object's bottom tracks window's bottom edge	*/

/*Hide or show the Finder and other applications*/
	pascal void FinderDisplay (Boolean Show);					/*Should the other apps be shown?				*/



/*=============================================== B U T T O N S ===============================================	*/
/*Create a new button*/
	pascal void NewButton (short Button,						/*Button number									*/
									short left,					/*Button's co-ordinates (local)					*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom,				/*												*/
									const Str255 Title,			/*Button's title								*/
									long Spec,					/*Button's appearance & behavior specifications	*/
									Boolean EnabledFlag,		/*Enable the button?							*/
									Boolean SelectedFlag);		/*Select the button?							*/

/*Create a new button (co-ordinates specified as a "rect") */
	pascal void NewButtonRect (short Button,					/*Button number									*/
									const Rect *Bounds,			/*Button's co-ordinates (local)					*/
									const Str255 Title,			/*Button's title								*/
									long Spec,					/*Button's appearance & behavior specifications	*/
									Boolean EnabledFlag,		/*Enable the button?							*/
									Boolean SelectedFlag);		/*Select the button?							*/

/*Set colors for new buttons*/
	pascal void ButtonColors (const RGBColor *Frame,			/*Frame's color									*/
									const RGBColor *Body,		/*Body's color									*/
									const RGBColor *Text,		/*Text's color									*/
									const RGBColor *Back);		/*Background color								*/

/*Reset button colors for new buttons to "black on white"*/
	pascal void NoButtonColors(void);

/*Delete a button*/
	pascal void DeleteButton (short Button);					/*Button number									*/

/*Delete a button without removing its image*/
	pascal void KillButton (short Button);						/*Button number									*/

/*Hide or show a button*/
	pascal void ButtonDisplay (short Button,					/*Button number									*/
									Boolean Show);				/*Should the button be shown					*/

/*Hide button but do not remove the image on the window*/
	pascal void ObscureButton (short Button);					/*Button number									*/

/*Get a button's co-ordinates*/
	pascal void GetButtonRect (short Button,					/*Button number									*/
									Rect *Bounds);				/*Enclosing rectangle co-ordinates (local)		*/

/*Enable/disable a button*/
	pascal void EnableButton (short Button,						/*Button number									*/
									Boolean EnabledFlag);		/*Enable the button?							*/

/*Select/deselect a button*/
	pascal void SelectButton (short Button,						/*Button number									*/
									Boolean SelectedFlag);		/*Select the button?							*/

/*Get a button's minimum setting (for custom CDEFs) */
	pascal short GetButtonMin (short Button						/*Button number									*/
									);							/*Button's minimum setting						*/

/*Set a button's minimum setting (for custom CDEFs) */
	pascal void SetButtonMin (short Button,						/*Button number									*/
									short minimum);				/*Button's minimum setting						*/

/*Get a button's maximum setting (for custom CDEFs) */
	pascal short GetButtonMax (short Button						/*Button number									*/
									);							/* = Button's maximum setting					*/

/*Set a button's maximum setting (for custom CDEFs) */
	pascal void SetButtonMax (short Button,						/*Button number									*/
									short maximum);				/*Button's maximum setting						*/

/*Get a button's current value (for custom CDEFs) */
	pascal short GetButtonVal (short Button						/*Button number									*/
									); 							/* = Button's current value						*/

/*Set a button's current value (for custom CDEFs) */
	pascal void SetButtonVal (short Button,						/*Button number									*/
									short value);				/*Button's current value						*/

/*Determine if a button is enabled*/
	pascal Boolean ButtonIsEnabled (short Button				/*Button number									*/
									);							/* = Is the button enabled?						*/

/*Determine if a button is selected*/
	pascal Boolean ButtonIsSelected (short Button				/*Button number									*/
									);							/* = Is the button selected?					*/

/*Set a button's title*/
	pascal void ButtonTitle (short Button,						/*Button number									*/
									const Str255 Title);		/*Button's title								*/

/*Set a button's colors*/
	pascal void SetButtonColors (short Button,					/*Button number									*/
									const RGBColor *Frame,		/*Frame's color									*/
									const RGBColor *Body,		/*Body's color									*/
									const RGBColor *Text,		/*Text's color									*/
									const RGBColor *Back);		/*Background color								*/

/*Get a button's colors*/
	pascal void GetButtonColors (short Button,					/*Button number									*/
									RGBColor *Frame,			/*Frame's color									*/
									RGBColor *Body,				/*Body's color									*/
									RGBColor *Text,				/*Text's color									*/
									RGBColor *Back);			/*Background color								*/

/*Make a button the window's default button*/
	pascal void SetDefaultButton (short Button);				/*Button number									*/

/*Remove the "default button status" from the window's default button*/
	pascal void NoDefaultButton(void);

/*"Flash" a push button as though it were pressed by the user*/
	pascal void FlashButton (short Button);						/*Button number									*/

/*Move a button to a new location*/
	pascal void MoveButton (short Button,						/*Button number									*/
									short toHoriz,				/*Horizontal position in local co-ordinates		*/
									short toVert);				/*Vertical position in local co-ordinates		*/

/*Move a button's co-ordinates to a new location without moving the image*/
	pascal void OffsetButton (short Button,						/*Button number									*/
									short distHoriz,			/*Number of pixels to be offset (horiz/vert)	*/
									short distVert);			/*												*/

/*Change a button's size*/
	pascal void SizeButton (short Button,						/*Button number									*/
									short width,				/*New width in pixels							*/
									short height);				/*New height in pixels							*/

/*Change a button's co-ordinates (size and/or location)*/
	pascal void MoveSizeButton (short Button,					/*Button number									*/
									short left,					/*Enclosing rectangle co-ordinates (local)		*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom);				/*												*/

/*Change a button's co-ordinates (size and/or location,  co-ordinates specified as a "rect") */
	pascal void MoveSizeButtonRect (short Button,				/*Button number									*/
									const Rect *Bounds);		/*Enclosing rectangle co-ordinates (local)		*/

/*Specify which sides of a button are automatically moved when the window is resized*/
	pascal void AutoMoveSizeButton (short Button,				/*Button number									*/
									Boolean left,				/*Button's left side tracks window's right edge	*/
									Boolean top,				/*Button's top tracks window's bottom edge		*/
									Boolean right,				/*Button's right side tracks window's right edge*/
									Boolean bottom);			/*Button's bottom tracks window's bottom edge	*/



/*======================================= P I C T U R E   B U T T O N S ======================================	*/
/*Create a new Picture Button*/
	pascal void NewPictButton (short Button,					/*Picture button number							*/
									short left,					/*Button's top-left corner in window's local	*/
									short top,					/*	co-ordinates.								*/
									short BaseID,				/*Base image's ID number						*/
									long Spec,					/*Appearance and Behavior specifications		*/
									Boolean EnabledFlag,		/*"Button is enabled" flag						*/
									Boolean SelectedFlag,		/*"Button is selected" flag						*/
									short minimum,				/*Minimum limit of button's value				*/
									short value,				/*Button's value								*/
									short maximum);				/*Maximum limit of button's value				*/

/*Delete a picture button*/
	pascal void DeletePictButton (short Button);				/*Picture button number							*/

/*Delete a picture button without removing its image*/
	pascal void KillPictButton (short Button);					/*Picture button number							*/

/*Get a picture button's co-ordinates*/
	pascal void GetPictButtonRect (short Button,				/*Picture button number							*/
									Rect *Bounds);				/*Enclosing rectangle co-ordinates (local)		*/

/*Hide or show a picture button*/
	pascal void PictButtonDisplay (short Button,				/*Picture button number							*/
									Boolean Show);				/*Should the button be shown					*/

/*Hide picture button but do not remove the image on the window*/
	pascal void ObscurePictButton (short Button);				/*Picture button number							*/

/*Enable/disable a picture button*/
	pascal void EnablePictButton (short Button,					/*Picture button number							*/
									Boolean EnabledFlag);		/*Enable the picture button?					*/

/*Select/deselect a picture button*/
	pascal void SelectPictButton (short Button,					/*Picture button number							*/
									Boolean SelectedFlag);		/*Select the picture button?					*/

/*Get a picture button's minimum setting*/
	pascal short GetPictButtonMin (short Button					/*Picture button number							*/
									);							/* = Picture button's minimum setting			*/

/*Set a picture button's minimum setting*/
	pascal void SetPictButtonMin (short Button,					/*Picture button number							*/
									short minimum);				/*Picture button's minimum setting				*/

/*Get a picture button's maximum setting*/
	pascal short GetPictButtonMax (short Button					/*Picture button number							*/
									);							/* = Picture button's maximum setting			*/

/*Set a picture button's maximum setting*/
	pascal void SetPictButtonMax (short Button,					/*Picture button number							*/
									short maximum);				/* = Picture button's maximum setting			*/

/*Get a picture button's current value*/
	pascal short GetPictButtonVal (short Button					/*Picture button number							*/
									);							/* = Picture button's current value				*/

/*Set a picture button's current value*/
	pascal void SetPictButtonVal (short Button,					/*Picture button number							*/
									short value);				/*Picture button's value						*/

/*Set a picture button's current value, and simultaneously select/deselect it*/
	pascal void SetPictButtonValSelect (short Button,			/*Picture button number							*/
									short value,				/*Picture button's value						*/
									Boolean SelectedFlag);		/*Select the picture button?					*/

/*Set a picture button's value acceleration "automatic value changing"*/
	pascal void SetPictButtonAccel (short Button,				/*Picture button number							*/
									short Rate);				/*0 = Linear, 1-3 = Slow to fast acceleration	*/

/*Set a picture button's speed for "automatic value changing"*/
	pascal void SetPictButtonSpeed (short Button,				/*Picture button number							*/
									short Rate);				/*Rate of change (value increment per second)	*/

/*Determine if a picture button is enabled*/
	pascal Boolean PictButtonIsEnabled (short Button			/*Picture button number							*/
									);							/* = Is the button enabled?						*/

/*Determine if a picture button is selected*/
	pascal Boolean PictButtonIsSelected (short Button			/*Picture button number							*/
									);							/* = Is the button selected?					*/

/*"Flash" a picture button as though it were pressed by the user*/
	pascal void FlashPictButton (short Button);					/*Picture button number							*/

/*Move a picture button to a new location*/
	pascal void MovePictButton (short Button,					/*Picture button number							*/
									short toHoriz,				/*Horizontal position in local co-ordinates		*/
									short toVert);				/*Vertical position in local co-ordinates		*/

/*Move a picture button's co-ordinates to a new location without moving the image*/
	pascal void OffsetPictButton (short Button,					/*Picture button number							*/
									short distHoriz,			/*Number of pixels to be offset (horiz/vert)	*/
									short distVert);			/*												*/

/*Specify which sides of a picture button are automatically moved when the window is resized*/
	pascal void AutoMoveSizePictButton (short Button,			/*Picture button number							*/
									Boolean left,				/*Button's left/right side track win right edge	*/
									Boolean top);				/*Button's top/bottom track window's bottom edge*/



/*=========================================== S C R O L L   B A R S ===========================================	*/
/*Create a new scroll bar*/
	pascal void NewScrollBar (short ScrollBar,					/*Scroll bar number								*/
									short left,					/*Scroll bar's co-ordinates (local)				*/
									short top,					/*												*/
									short right, 				/*												*/
									short bottom,				/*												*/
									long Spec,					/*Appearance and behavior specification			*/
									Boolean EnabledFlag,		/*Enable the scroll bar							*/
									short minimum,				/*Minimum, current, and maximum value			*/
									short value,				/*												*/
									short maximum);				/*												*/

/*Create a new scroll bar (co-ordinates specified as a "rect") */
	pascal void NewScrollBarRect (short ScrollBar,				/*Scroll bar number								*/
									const Rect *Bounds,			/*Scroll bar's co-ordinates (local)				*/
									long Spec,					/*Appearance and behavior specification			*/
									Boolean EnabledFlag,		/*Enable the scroll bar?						*/
									short minimum,				/*Minimum, current, and maximum value			*/
									short value,				/*												*/
									short maximum);				/*												*/

/*Set colors for new scroll bars (for custom CDEFs) */
	pascal void ScrollBarColors (const RGBColor *Frame,			/*Frame's color									*/
									const RGBColor *Body,		/*Body's color									*/
									const RGBColor *Text,		/*Text's color									*/
									const RGBColor *Thumb,		/*Thumb's color									*/
									const RGBColor *Back);		/*Background color								*/

/*Reset scroll bar colors for new scroll bars to "black on white" (for custom CDEFs) */
	pascal void NoScrollBarColors(void);

/*Delete a scroll bar*/
	pascal void DeleteScrollBar (short ScrollBar);				/*Scroll bar number								*/

/*Delete a scroll bar without removing its image*/
	pascal void KillScrollBar (short ScrollBar);				/*Scroll bar number								*/

/*Get a scroll bar's co-ordinates*/
	pascal void GetScrollBarRect (short ScrollBar,				/*Scroll bar number								*/
									short *Bounds);				/*Enclosing rectangle co-ordinates (local)		*/

/*Hide or show a scroll bar*/
	pascal void ScrollBarDisplay (short ScrollBar,				/*Scroll bar number								*/
									Boolean Show);				/*Should the scroll bar be shown				*/

/*Hide scroll bar but do not remove the image on the window*/
	pascal void ObscureScrollBar (short ScrollBar);				/*Scroll bar number								*/

/*Enable/disable a scroll bar*/
	pascal void EnableScrollBar (short ScrollBar,				/*Scroll bar number								*/
									Boolean EnabledFlag);		/*Enable the scroll bar?						*/

/*Get a scroll bar's minimum setting*/
	pascal short GetScrollBarMin (short ScrollBar				/*Scroll bar number								*/
									);							/*Scroll bar's minimum setting					*/

/*Set a scroll bar's minimum setting*/
	pascal void SetScrollBarMin (short ScrollBar,				/*Scroll bar number								*/
									short minimum);				/*Scroll bar's minimum setting					*/

/*Get a scroll bar's maximum setting*/
	pascal short GetScrollBarMax (short ScrollBar				/*Scroll bar number								*/
									);							/* = Scroll bar's maximum setting				*/

/*Set a scroll bar's maximum setting*/
	pascal void SetScrollBarMax (short ScrollBar,				/*Scroll bar number								*/
									short maximum);				/*Scroll bar's maximum setting					*/

/*Get a scroll bar's current value*/
	pascal short GetScrollBarVal (short ScrollBar				/*Scroll bar number								*/
									); 							/* = Scroll bar's current value					*/

/*Set a scroll bar's current value*/
	pascal void SetScrollBarVal (short ScrollBar,				/*Scroll bar number								*/
									short value);				/*Scroll bar's current value					*/

/*Set a scroll bar's color (for custom CDEFs) */
	pascal void SetScrollBarColors (short ScrollBar,			/*Scroll bar number								*/
									const RGBColor *Frame,		/*Frame's color									*/
									const RGBColor *Body,		/*Body's color									*/
									const RGBColor *Text,		/*Text's color									*/
									const RGBColor *Thumb,		/*Thumb's color									*/
									const RGBColor *Back);		/*Background color								*/

/*Get a scroll bar's colors (for custom CDEFs) */
	pascal void GetScrollBarColors (short ScrollBar,			/*Scroll bar number								*/
									RGBColor *Frame,			/*Frame's color									*/
									RGBColor *Body,				/*Body's color									*/
									RGBColor *Text,				/*Text's color									*/
									RGBColor *Thumb,			/*Thumb's color									*/
									RGBColor *Back);			/*Background color								*/

/*Move a scroll bar to a new location*/
	pascal void MoveScrollBar (short ScrollBar,					/*Scroll bar number								*/
									short toHoriz,				/*Horizontal position in local co-ordinates		*/
									short toVert);				/*Vertical position in local co-ordinates		*/

/*Move a scroll bar's co-ordinates to a new location without moving the image*/
	pascal void OffsetScrollBar (short ScrollBar,				/*Scroll bar number								*/
									short distHoriz,			/*Number of pixels to be offset (horiz/vert)	*/
									short distVert);			/*												*/

/*Change a scroll bar's size*/
	pascal void SizeScrollBar (short ScrollBar,					/*Scroll bar number								*/
									short width,				/*New width in pixels							*/
									short height);				/*New height in pixels							*/

/*Change a scroll bar's co-ordinates (size and/or location)*/
	pascal void MoveSizeScrollBar (short ScrollBar,				/*Scroll bar number								*/
									short left,					/*Enclosing rectangle co-ordinates (local)		*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom);				/*												*/

/*Change a scroll bar's co-ordinates (size and/or location,  co-ordinates specified as a "rect") */
	pascal void MoveSizeScrollBarRect (short ScrollBar,			/*Scroll bar number								*/
									const *Bounds);				/*Enclosing rectangle co-ordinates (local)		*/

/*Specify which sides of a scroll bar are automatically moved when the window is resized*/
	pascal void AutoMoveSizeScrollBar (short ScrollBar,			/*Scroll bar number								*/
									Boolean left,				/*Scrl bar's left side tracks window's right	*/
									Boolean top,				/*Scrl bar's top tracks window's bottom edge	*/
									Boolean right,				/*Scrl bar's right side tracks window's right	*/
									Boolean bottom);			/*Scrl bar's bottom tracks window's bottom edge	*/

/*Set time between line up/down events for new scroll bars (scroll bar throttling)		[Developer Kit bonus]	*/
	pascal void ScrollBarLineTime (short Ticks);				/*Number of ticks between line up/down events	*/

/*Set time between page up/down events for new scroll bars (scroll bar throttling)		[Developer Kit bonus]	*/
	pascal void ScrollBarPageTime (short Ticks);				/*Number of ticks between page up/down events	*/

/*Set a scroll bar's time between line up/down events (scroll bar throttling)			[Developer Kit bonus]	*/
	pascal void SetScrollBarLineTime (short ScrollBar,			/*Scroll bar number								*/
									short Ticks);				/*Number of ticks between line up/down events	*/

/*Set a scroll bar's time between page up/down events (scroll bar throttling)			[Developer Kit bonus]	*/
	pascal void SetScrollBarPageTime (short ScrollBar,			/*Scroll bar number								*/
									short Ticks);				/*Number of ticks between page up/down events	*/

/*Set an action routine for a scroll bar*/
	pascal void SetScrollBarAction (short ScrollBar,			/*Scroll bar number								*/
									ControlActionUPP ActionProc);/*Action proc (called during tracking)			*/

/*Get info about the scroll bar currently calling an action routine*/
	pascal void GetScrollBarActionInfo (short *Window,			/*Window number containing the scroll bar		*/
									short *ScrollBar,			/*Scroll bar number								*/
									short *Part,				/*Part of scroll bar originally clicked			*/
									Boolean *InPart);			/*Is mouse still in the part?					*/



/*======================================== E D I T I N G   F I E L D S ========================================	*/
/*Allocate heap storage for a string, and initialize it.*/
	pascal StringHandle NewStrHandle (short StringLen			/*Size of string being allocated (1-32767 chars)*/
									);							/*Handle to allocated string					*/

/*Create a new field*/
	pascal void NewField (short Field,							/*Field number									*/
									short left, 				/*Field's viewing area co-ordinates (local)		*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom,				/*												*/
									Handle hStr,				/*Handle to edit field's text. NIL=auto allocate*/
									long Spec,					/*Behavior and display specifications			*/
									short Just);				/*Justification: left, centre, right			*/

/*Create a new field (co-ordinates specified as a "rect") */
	pascal void NewFieldRect (short Field,						/*Field number									*/
									const Rect *Bounds, 		/*Field's viewing area co-ordinates (local)		*/
									Handle hStr,				/*Handle to edit field's text. NIL=auto allocate*/
									long Spec,					/*Behavior and display specifications			*/
									short Just);				/*Justification: left, centre, right			*/

/*Create a new field with a horizontal scroll bar*/
	pascal void NewWideField (short Field,						/*Field number									*/
									short left, 				/*Field's viewing area co-ordinates (local)		*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom,				/*												*/
									short DestWidth,			/*Destination area's width						*/
									Handle hStr,				/*Handle to edit field's text. NIL=auto allocate*/
									long Spec,					/*Behavior and display specifications			*/
									short Just);				/*Justification: left, centre, right			*/

/*Create a new field with a horizontal scroll bar (co-ordinates specified as a "rect") */
	pascal void NewWideFieldRect (short Field,					/*Field number									*/
									const Rect *Bounds, 		/*Field's viewing area co-ordinates (local)		*/
									short DestWidth,			/*Destination area's width						*/
									Handle hStr,				/*Handle to edit field's text. NIL=auto allocate*/
									long Spec,					/*Behavior and display specifications			*/
									short Just);				/*Justification: left, centre, right			*/

/*Delete a field*/
	pascal void DeleteField (short Field);						/*Field number									*/

/*Delete a field without removing its image*/
	pascal void KillField (short Field);						/*Field number									*/

/*Get a field's co-ordinates*/
	pascal void GetFieldRect (short Field,						/*Field number									*/
									Rect *Bounds);				/*Enclosing rectangle co-ordinates (local)		*/

/*Hide or show a field*/
	pascal void FieldDisplay (short Field,						/*Field number									*/
									Boolean Show);				/*Should the field be shown						*/

/*Hide field but do not remove the image on the window*/
	pascal void ObscureField (short Field);						/*Field number									*/

/*Get a field's colors*/
	pascal void GetFieldColors (short Field,					/*Field number									*/
									RGBColor *TextColor,		/*Text's color									*/
									RGBColor *BackColor);		/*Background color								*/

/*Set a field's colors*/
	pascal void SetFieldColors (short Field,					/*Field number									*/
									const RGBColor *TextColor,	/*Text's color									*/
									const RGBColor *BackColor);	/*Background color								*/

/*Activate a field*/
	pascal void ActivateField (short Field,						/*Field number									*/
									short Selection);			/*Text selection: start, end, all or default	*/

/*Deactivate the active field*/
	pascal void DeactivateField(void);
	
/*Enable/disable a field*/
	pascal void EnableField (short Field,						/*Field number									*/
									Boolean EnabledFlag);		/*Enable the field								*/

/*Process a mouse click in an inactive field. The click has been detected by the PollSystem routine.*/
	pascal void ClickInField(void);

/*Determine if the user pressed the Tab key in an active field*/
	pascal Boolean HaveTabInField(void);						/* = Was Tab used in the active field?			*/

/*Process a Tab in an active field.  The Tab has been detected by the PollSystem procedure.*/
	pascal void TabToField(void);

/*Get the active field's edited text*/
	pascal void GetEditString (Str255 EditString);				/*Field's edited text							*/

/*Get a handle to the active field's edited text*/
	pascal Handle GetEditHandle(void);							/*Handle to active field's edited text			*/

/*Get the length (number of chars) in the active field's edited text*/
	pascal short GetEditLength(void);							/* = No. of chars in active field's edited text	*/


/*Get a field's string*/
	pascal void GetFieldString (short Field,					/*Field number									*/
									Str255 EditString);			/*Copy of field's string						*/

/*Get a handle to a field's string*/
	pascal Handle GetFieldHandle (short Field					/*Field number									*/
									);							/* = Handle to field's string					*/

/*Get the length (number of chars) in a field's string*/
	pascal short GetFieldLength (short Field					/*Field number									*/
									);							/* = Number of chars in field's string			*/

/*Determine if a field is empty*/
	pascal Boolean FieldIsEmpty (short Field					/*Field number									*/
									);							/* = Is the specified field empty?				*/

/*Save the active field's edited text in the field's string*/
	pascal void SaveFieldString(void);

/*Determine the active field number*/
	pascal short ActiveFieldNumber(void);						/*Active field number							*/

/*Turn string length limiting on/off for fields created after using this routine*/
	pascal void FieldLengthLimit (Boolean Limits);				/*Are newly created fields length-limited?		*/

/*Turn automatic handle sizing on/off for fields created after using this routine*/
	pascal void DynamicFieldHandles (Boolean Resize);			/*Are newly created fields' handles resizable?	*/

/*Specify the "disabled" appearance and behavior for fields created after using this routine*/
	pascal void DisabledFieldLook (long DimFieldSpec);			/*Specification for new disabled fields			*/

/*Specify the "disabled" appearance and behavior for a field*/
	pascal void SetDisabledFieldLook (short Field,				/*Field number									*/
									long DimFieldSpec);		/*Specification for disabled appearance			*/

/*Scroll a field's text back to its default position*/
	pascal void ResetFieldScrolling (short Field);				/*Field number									*/

/*Paste a string into a field*/
	pascal void PasteIntoField (short Field,					/*Field number									*/
									const Str255 Text,			/*Text being pasted into the field				*/
									Boolean Replace);			/*Replace all existing text in field			*/

/*Paste text into a field using a pointer*/
	pascal void PastePIntoField (short Field,					/*Field number									*/
									Ptr Text,					/*Pointer to text being pasted into the field	*/
									short TextLength,			/*Number of characters being pasted				*/
									Boolean Replace);			/*Replace all existing text in field			*/

/*Paste text into a field using a handle*/
	pascal void PasteHIntoField (short Field,					/*Field number									*/
									Handle Text,				/*Handle to text being pasted into the field	*/
									short TextLength,			/*Number of characters being pasted				*/
									Boolean Replace);			/*Replace all existing text in field			*/

/*Move a field to a new location*/
	pascal void MoveField (short Field,							/*Field number									*/
									short toHoriz,				/*Horizontal position in local co-ordinates		*/
									short toVert);				/*Vertical position in local co-ordinates		*/

/*Move a field's co-ordinates to a new location without moving the image*/
	pascal void OffsetField (short Field,						/*Field number									*/
									short distHoriz,			/*Number of pixels to be offset (horiz/vert)	*/
									short distVert);			/*												*/

/*Change a field's size*/
	pascal void SizeField (short Field,							/*Field number									*/
									short width,				/*New width in pixels							*/
									short height);				/*New height in pixels							*/

/*Change a field's co-ordinates (size and/or location)*/
	pascal void MoveSizeField (short Field,						/*Field number									*/
									short left,					/*Enclosing rectangle co-ordinates (local)		*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom);				/*												*/

/*Change a field's co-ordinates (size and/or location,  co-ordinates specified as a "rect") */
	pascal void MoveSizeFieldRect (short Field,					/*Field number									*/
									const Rect *Bounds);		/*Enclosing rectangle co-ordinates (local)		*/

/*Specify which sides of a field are automatically moved when the window is resized*/
	pascal void AutoMoveSizeField (short Field,					/*Field number									*/
									Boolean left,				/*Field's left side tracks window's right edge	*/
									Boolean top,				/*Field's top tracks window's bottom edge		*/
									Boolean right,				/*Field's right side tracks window's right edge	*/
									Boolean bottom);			/*Field's bottom tracks window's bottom edge	*/

/*Define a new field filter and get its Filter Reference Number*/
	pascal short NewFieldFilter (const Str255 Chars,			/*The filter's characters						*/
									long FilterSpec				/*Filter specifications							*/
									);							/* = Filter Reference Number					*/

/*Specify the filter used by fields created after using this routine*/
	pascal void CurrentFieldFilter (short FilterRefNum);		/*Filter Reference Number (negative = disallow)	*/

/*Set a field's filter*/
	pascal void SetFieldFilter (short Field,					/*Field number									*/
									short FilterRefNum);		/*Filter Reference Number (negative = disallow)	*/

/*Specify min. free memory required after "undo" is set up								[Developer Kit bonus]	*/
	pascal void SetTENoUndoThresh (long Threshold);				/*Memory threshold								*/

/*Specify min. free memory below which text editing is disallowed						[Developer Kit bonus]	*/
	pascal void SetTENoEditThresh (long Threshold);				/*Memory threshold								*/

/*Specify min. free memory below which "low memory" warning is displayed while typing	[Developer Kit bonus]	*/
	pascal void SetTELowMemThresh (long Threshold);				/*Memory threshold								*/



/*============================================ L I S T   B O X E S ============================================	*/
/*Create a new List Box*/
	pascal void NewListBox (short ListBox,						/*List box number								*/
									short left,					/*List box co-ordinates (local)					*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom,				/*												*/						
									long Spec);					/*Type of responses to mouse clicks, shift-		*/
																/*	click, dragging, etc.						*/

/*Create a new List Box (co-ordinates specified as a "rect") */
	pascal void NewListBoxRect (short ListBox,					/*List box number								*/
									const Rect *Bounds,			/*List box co-ordinates (local)					*/
									long Spec);					/*Type of responses to mouse clicks, shift-		*/
																/*	click, dragging, etc.						*/

/*Delete a List Box*/
	pascal void DeleteListBox (short ListBox);					/*List box number								*/

/*Delete a list box without removing its image*/
	pascal void KillListBox (short ListBox);					/*List box number								*/

/*Get a list box's co-ordinates*/
	pascal void GetListBoxRect (short ListBox,					/*List box number								*/
									Rect *Bounds);				/*Enclosing rectangle co-ordinates (local)		*/

/*Hide or show a List Box*/
	pascal void ListBoxDisplay (short ListBox,					/*List box number								*/
									Boolean Show);				/*Should the list box be shown					*/

/*Hide List Box but do not remove the image on the window*/
	pascal void ObscureListBox (short ListBox);					/*List box number								*/

/*Set a line of text in a List Box*/
	pascal void SetListBoxText (short ListBox,					/*List box number								*/
									short LineNum,				/*Line number									*/
									const Str255 Text);			/*Text of specified line number					*/

/*Insert resource names in a List Box*/
	pascal void ResNamesToListBox (short ListBox,				/*List box number								*/
									short LineNum,				/*Line number									*/
									ResType rType);				/*Resource type									*/

/*Get a line of text from a List Box*/
	pascal void GetListBoxText (short ListBox,					/*List box number								*/
									short LineNum,				/*Line number									*/
									Str255 Text);				/*Text of specified line number					*/

/*Get a List Box's line number whose text is greater than or equal to the specified string*/
	pascal short SearchListBox (short ListBox,					/*List box number								*/
									const Str255 Text			/*Text being compared							*/
									);							/* = Line number of text						*/

/*Select/deselect a specified List Box line*/
	pascal void SetListBoxLine (short ListBox,					/*List box number								*/
									short LineNum,				/*Line number									*/
									Boolean SetIt);				/*Selects the line								*/

/*Determine if a specific List Box line is selected*/
	pascal Boolean GetListBoxLine (short ListBox,				/*List box number								*/
									short LineNum				/*Line number									*/
									);							/* = Is the line selected?						*/

/*Get the line number of a selected line in a List Box, starting at LineNum and searching down*/
	pascal short GetListBoxLines (short ListBox,				/*List box number								*/
									short LineNum				/*Line number									*/
									);							/* = Next selected line							*/

/*Insert a blank line into a List Box*/
	pascal void InsertListBoxLine (short ListBox,				/*List box number								*/
									short LineNum);				/*Line number									*/

/*Delete a line from a List Box*/
	pascal void DeleteListBoxLine (short ListBox,				/*List box number								*/
									short LineNum);				/*Line number									*/

/*Delete all lines in a List Box*/
	pascal void ClearListBox (short ListBox);					/*List box number								*/

/*Get a List Box's colors*/
	pascal void GetListBoxColors (short ListBox,				/*List box number								*/
									RGBColor *TextColor,		/*Text's color									*/
									RGBColor *BackColor);		/*Background color								*/

/*Set a List Box's colors*/
	pascal void SetListBoxColors (short ListBox,				/*List box number								*/
									const RGBColor *TextColor,	/*Text's color									*/
									const RGBColor *BackColor);	/*Background color								*/

/*Determine the number of items in a List Box*/
	pascal short ListBoxLineCount (short ListBox				/*List box number								*/
									);							/* = Number of lines in the list box			*/

/*Turn a List Box's text drawing on/off*/
	pascal void DrawListBox (short ListBox,						/*List box number								*/
									Boolean DrawIt);			/*Draw the list box's text						*/

/*Move a list box to a new location*/
	pascal void MoveListBox (short ListBox,						/*List box number								*/
									short toHoriz,				/*Horizontal position in local co-ordinates		*/
									short toVert);				/*Vertical position in local co-ordinates		*/

/*Move a list box's co-ordinates to a new location without moving the image*/
	pascal void OffsetListBox (short ListBox,					/*List box number								*/
									short distHoriz,			/*Number of pixels to be offset (horiz/vert)	*/
									short distVert);			/*												*/

/*Change a list box's size*/
	pascal void SizeListBox (short ListBox,						/*List box number								*/
									short width,				/*New width in pixels							*/
									short height);				/*New height in pixels							*/

/*Change a list box's co-ordinates (size and/or location)*/
	pascal void MoveSizeListBox (short ListBox,					/*List box number								*/
									short left,					/*Enclosing rectangle co-ordinates (local)		*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom);				/*												*/

/*Change a list box's co-ordinates (size and/or location,  co-ordinates specified as a "rect") */
	pascal void MoveSizeListBoxRect (short ListBox,				/*List box number								*/
									const Rect *Bounds);		/*Enclosing rectangle co-ordinates (local)		*/

/*Specify which sides of a list box are automatically moved when the window is resized*/
	pascal void AutoMoveSizeListBox (short ListBox,				/*List box number								*/
									Boolean left,				/*List box's left side tracks window's right	*/
									Boolean top,				/*List box's top tracks window's bottom edge	*/
									Boolean right,				/*List box's right side tracks window's right	*/
									Boolean bottom);			/*List box's bottom tracks window's bottom edge	*/



/*================================================ P A N E L S ================================================	*/
/*Create a new panel*/
	pascal void NewPanel (short Panel,							/*Panel number									*/
									short left,					/*Enclosing rectangle co-ordinates (local)		*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom,				/*												*/
									const Str255 Title,			/*Panel's title (if applicable)					*/
									long Spec,					/*Panel's appearance & behavior specification	*/
									short ShadowWidth);			/*Shadow's width in pixels						*/

/*Create a new panel (co-ordinates specified as a "rect") */
	pascal void NewPanelRect (short Panel,						/*Panel number									*/
									const Rect *Bounds,			/*Enclosing rectangle co-ordinates (local)		*/
									const Str255 Title,			/*Panel's title (if applicable)					*/
									long Spec,					/*Panel's appearance & behavior specification	*/
									short ShadowWidth);			/*Shadow's width in pixels						*/

/*Set standard panel colors used throughout application*/
	pascal void SetStandardPanelColors (const RGBColor *Text,	/*Text color									*/
									const RGBColor *Background,	/*Background color								*/
									const RGBColor *Border,		/*Border's color								*/
									const RGBColor *Hilite,		/*Highlight color								*/
									const RGBColor *Shadow,		/*Shadow color for panels						*/
									const RGBColor *TextShadow,	/*Shadow color for text							*/
									const RGBColor *TextHeavyShadow);	/*Heavy shadow color for text			*/

/*Get standard panel colors used throughout application*/
	pascal void GetStandardPanelColors (RGBColor *Text,			/*Text color									*/
									RGBColor *Background,		/*Background color								*/
									RGBColor *Border,			/*Border's color								*/
									RGBColor *Hilite,			/*Highlight color								*/
									RGBColor *Shadow,			/*Shadow color for panels						*/
									RGBColor *TextShadow,		/*Shadow color for text							*/
									RGBColor *TextHeavyShadow);	/*Heavy shadow color for text					*/

/*Set custom panel colors adopted by new panels*/
	pascal void SetCustomPanelColors (const RGBColor *Text,		/*Text color									*/
									const RGBColor *Background,	/*Background color								*/
									const RGBColor *Border,		/*Border's color								*/
									const RGBColor *Hilite,		/*Highlight color								*/
									const RGBColor *Shadow,		/*Shadow color for panels						*/
									const RGBColor *TextShadow,	/*Shadow color for text							*/
									const RGBColor *TextHeavyShadow);	/*Heavy shadow color for text			*/

/*Set custom panel colors adopted by new panels*/
	pascal void GetCustomPanelColors (RGBColor *Text,			/*Text color									*/
									RGBColor *Background,		/*Background color								*/
									RGBColor *Border,			/*Border's color								*/
									RGBColor *Hilite,			/*Highlight color								*/
									RGBColor *Shadow,			/*Shadow color for panels						*/
									RGBColor *TextShadow,		/*Shadow color for text							*/
									RGBColor *TextHeavyShadow);	/*Heavy shadow color for text					*/

/*Delete a panel*/
	pascal void DeletePanel (short Panel);						/*Panel number									*/

/*Delete a panel without removing its image*/
	pascal void KillPanel (short Panel);						/*Panel number									*/

/*Get a panel's co-ordinates*/
	pascal void GetPanelRect (short Panel,						/*Panel number									*/
									Rect *Bounds);				/*Enclosing rectangle co-ordinates (local)		*/

/*Hide or show a panel*/
	pascal void PanelDisplay (short Panel,						/*Panel number									*/
									Boolean Show);				/*Should the panel be shown?					*/

/*Hide panel but do not remove the image on the window*/
	pascal void ObscurePanel (short Panel);						/*Panel number									*/

/*Set a panel's colors*/
	pascal void SetPanelColors (short Panel,					/*Panel number									*/
									const RGBColor *Text,		/*Text color									*/
									const RGBColor *Background,	/*Background color								*/
									const RGBColor *Border,		/*Border's color								*/
									const RGBColor *Hilite,		/*Highlight color								*/
									const RGBColor *Shadow,		/*Shadow color for panels						*/
									const RGBColor *TextShadow,	/*Shadow color for text							*/
									const RGBColor *TextHeavyShadow);	/*Heavy shadow color for text			*/
																	
/*Get a panel's colors*/
	pascal void GetPanelColors (short Panel,					/*Panel number									*/
									RGBColor *Text,				/*Text color									*/
									RGBColor *Background,		/*Background color								*/
									RGBColor *Border,			/*Border's color								*/
									RGBColor *Hilite,			/*Highlight color								*/
									RGBColor *Shadow,			/*Shadow color for panels						*/
									RGBColor *TextShadow,		/*Shadow color for text							*/
									RGBColor *TextHeavyShadow);	/*Heavy shadow color for text					*/

/*Move a panel to a new location*/
	pascal void MovePanel (short Panel,							/*Panel number									*/
									short toHoriz,				/*Horizontal position in local co-ordinates		*/
									short toVert);				/*Vertical position in local co-ordinates		*/

/*Move a panel's co-ordinates to a new location without moving the image*/
	pascal void OffsetPanel (short Panel,						/*Panel number									*/
									short distHoriz,			/*Number of pixels to be offset (horizontal)	*/
									short distVert);			/*Number of pixels to be offset (vertical)		*/

/*Change a panel's size*/
	pascal void SizePanel (short Panel,							/*Panel number									*/
									short width,				/*New width in pixels							*/
									short height);				/*New height in pixels							*/

/*Change a panel's co-ordinates (size and/or location)*/
	pascal void MoveSizePanel (short Panel,						/*Panel number									*/
									short left,					/*Enclosing rectangle co-ordinates (local)		*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom);				/*												*/

/*Change a panel's co-ordinates (size and/or location,  co-ordinates specified as a "rect") */
	pascal void MoveSizePanelRect (short Panel,					/*Panel number									*/
									const Rect *Bounds);		/*Enclosing rectangle co-ordinates (local)		*/

/*Specify which sides of a panel are automatically altered when the window is resized*/
	pascal void AutoMoveSizePanel (short Panel,					/*Panel number									*/
									Boolean left,				/*Panel's left side tracks windows right edge	*/
									Boolean top,				/*Panel's top tracks windows bottom edge		*/
									Boolean right,				/*Panel's right side tracks windows right edge	*/
									Boolean bottom);			/*Panel's bottom tracks windows bottom edge		*/



/*================================================= M E N U S =================================================	*/
/*Create the "Apple" menu*/
	pascal void AppleMenu (const Str255 AboutName);				/*Optional "About" name						*/

/*Declare that a "Select All" item exists in the Edit menu*/
	pascal void SetSelectAllItem (short ItemNumber);			/*Item number within the Edit menu (0=n/a)		*/

/*Create a menu name, add/change a menu item, or rename an existing menu item*/
	pascal void Menu (short MenuNumber,							/*Menu number									*/
									short ItemNumber,			/*Item number within the menu					*/
									Boolean EnabledFlag,		/*Enable the menu								*/
									const Str255 MenuText);		/*Menu title or item name						*/

/*Attach a hierarchical menu to a menu item, or detach a hierarchical menu*/
	pascal void AttachMenu (short MenuNumber,					/*Menu number to which the submenu is attached	*/
									short ItemNumber,			/*Item number to which the submenu is attached	*/
									short SubMenuNumber);		/*Hierarchical menu number being attached		*/

/*Insert a menu item*/
	pascal void InsertMenuItm (short MenuNumber,				/*Menu number									*/
									short ItemNumber,			/*Item number where insertion is to be made		*/
									Boolean EnabledFlag,		/*Enable the menu								*/
									const Str255 MenuText);		/*Item name										*/

/*Insert resource names in a menu*/
	pascal void ResNamesToMenu (short MenuNumber,				/*Menu number									*/
									short ItemNumber,			/*Item number where insertion is to be made		*/
									ResType rType);				/*Resource type									*/

/*Remove an entire menu and its associated items, or a menu item*/
	pascal void RemoveMenu (short MenuNumber,					/*Menu number									*/
									short ItemNumber);			/*Item number within the menu (0=entire menu)	*/

/*Delete all application menus in the menu bar (except Apple Menu)*/
	pascal void RemoveMenus(void);

/*Delete all application menus in the menu bar (except Apple menu) and all hierarchical menus*/
	pascal void RemoveAllMenus(void);

/*Display the menu bar after making changes through the Menu or RemoveMenu procedure*/
	pascal void UpdateMenuBar(void);

/*Hide or show the menu bar*/
	pascal void MenuBarDisplay (Boolean Show);					/*Should the menu bar be shown?					*/

/*Get a menu item's text*/
	pascal void GetMenuString (short MenuNumber,				/*Menu number									*/
									short ItemNumber,			/*Item number within the menu					*/
									Str255 MenuText);			/*Menu item's name								*/

/*Change the name of a menu item*/
	pascal void RenameItem (short MenuNumber,					/*Menu number									*/
									short ItemNumber,			/*Item number within the menu					*/
									const Str255 MenuText);		/*Menu item's name								*/

/*Enable/disable a menu or menu item*/
	pascal void EnableMenu (short MenuNumber,					/*Menu number									*/
									short ItemNumber,			/*Item number within the menu (or 0)			*/
									Boolean EnabledFlag);		/*Enable the menu or item						*/

/*Display/remove a menu item's check mark*/
	pascal void CheckMenu (short MenuNumber,					/*Menu number									*/
									short ItemNumber,			/*Item number within the menu					*/
									Boolean checked);			/*Place check mark beside the menu item			*/

/*Mark a menu item with a specified character ( or , etc)*/
	pascal void MenuMark (short MenuNumber,						/*Menu number									*/
									short ItemNumber,			/*Item number within the menu					*/
									char markChar);				/*Menu item's character							*/

/*Get a menu item's "mark" character ( or , etc) which is optionally displayed at the item's left side*/
	pascal void GetMenuMark (short MenuNumber,					/*Menu number									*/
									short ItemNumber,			/*Item number within the menu					*/
									char *markChar);			/*Menu item's character							*/

/*Specify a keyboard equivalent for a menu item*/
	pascal void MenuCmd (short MenuNumber,						/*Menu number									*/
									short ItemNumber,			/*Item number within the menu					*/
									char cmdChar);				/*Menu item's keyboard-equivalent character		*/

/*Get a keyboard equivalent for a menu item*/
	pascal void GetMenuCmd (short MenuNumber,					/*Menu number									*/
									short ItemNumber,			/*Item number within the menu					*/
									char *cmdChar);				/*Menu item's keyboard-equivalent character		*/

/*Specify an icon to be displayed by a menu item*/
	pascal void MenuIcon (short MenuNumber,						/*Menu number									*/
									short ItemNumber,			/*Item number within the menu					*/
									short IconSelector);		/*IconSelector + 256 = Icon ID number			*/

/*Get the specifier for the icon that is displayed by a menu item*/
	pascal void GetMenuIcon (short MenuNumber,					/*Menu number									*/
									short ItemNumber,			/*Item number within the menu					*/
									short *IconSelector);		/*IconSelector + 256 = Icon ID number			*/

/*Set the character style for a menu item*/
	pascal void MenuStyle (short MenuNumber,					/*Menu number									*/
									short ItemNumber,			/*Item number within the menu					*/
									Style theStyle);			/*Menu item's character style					*/

/*Determine the number of items in a menu*/
	pascal short MenuItemCount (short MenuNumber				/*Menu number									*/
									);							/* =Number of items in the menu					*/

/*Determine a menu's parent menu number*/
 	pascal void GetParentMenu (short *MenuNumber,				/*Parent menu's menu number						*/
									short *ItemNumber,			/*Parent menu's item number 					*/
									short SubMenuNumber);		/*Menu number whose parent menu is determined	*/

/*Determine a menu item's submenu number*/
 	pascal void GetSubMenu (short MenuNumber,					/*Menu number									*/
									short ItemNumber,			/*Item number within the menu					*/
									short *SubMenuNumber);		/*Menu number of this item's submenu			*/

/*Highlight a menu in the menu bar, or turn off menu bar highlights*/
	pascal void MenuHilite (short MenuNumber);					/*Menu number									*/



/*========================================== P O P - U P   M E N U S ==========================================	*/
/*Create a new Pop-Up menu*/
	pascal void NewPopUp (short MenuNumber,						/*Pop-Up Menu number							*/
									short left,					/*Enclosing rectangle co-ordinates (local)		*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom,				/*												*/
									const Str255 MenuTitle,		/*Title											*/
									long Spec,					/*Appearance and behavior specifications		*/
									Boolean EnabledFlag);		/*"Menu is enabled" flag						*/

/*Create a new Pop-Up menu (co-ordinates specified as a "rect") */
	pascal void NewPopUpRect (short MenuNumber,					/*Pop-Up Menu number							*/
									const Rect *Bounds,			/*Enclosing rectangle co-ordinates (local)		*/
									const Str255 MenuTitle,		/*Title											*/
									long Spec,					/*Appearance and behavior specifications		*/
									Boolean EnabledFlag);		/*"Menu is enabled" flag						*/

/*Add or change a Pop-Up menu item, or rename an existing menu item*/
	pascal void PopUpMenu (short MenuNumber,					/*Pop-Up Menu number							*/
									short ItemNumber,			/*Item number within the menu					*/
									Boolean EnabledFlag,		/*Enable the menu								*/
									const Str255 MenuText);		/*Item name										*/

/*Insert a Pop-Up menu item in the "current" window*/
	pascal void InsertPopUpItem (short MenuNumber,				/*Pop-Up Menu number							*/
									short ItemNumber,			/*Item number where insertion is to be made		*/
									Boolean EnabledFlag,		/*Is menu item enabled							*/
									const Str255 MenuText);		/*Item name										*/

/*Insert resource names in a Pop-Up menu*/
	pascal void ResNamesToPopUp (short MenuNumber,				/*Pop-Up Menu number							*/
									short ItemNumber,			/*Item number where insertion is to be made		*/
									ResType rType);				/*Resource type									*/

/*Remove an Pop-Up menu, or a Pop-Up menu item*/
	pascal void RemovePopUp (short MenuNumber,					/*Pop-Up Menu number							*/
									short ItemNumber);			/*Item number within the menu (0=entire menu)	*/

/*Delete all items in a Pop-Up menu*/
	pascal void ClearPopUp (short MenuNumber);					/*Pop-Up Menu number							*/

/*Delete a pop-up menu without removing its image*/
	pascal void KillPopUp (short MenuNumber);					/*Pop-Up menu number							*/

/*Get a pop-up menu's co-ordinates*/
	pascal void GetPopUpRect (short MenuNumber,					/*Pop-Up menu number							*/
									Rect *Bounds);				/*Enclosing rectangle co-ordinates (local)		*/

/*Hide or show a Pop-Up menu*/
	pascal void PopUpDisplay (short MenuNumber,					/*Pop-Up Menu number							*/
									Boolean Show);				/*Should the Pop-Up Menu be shown				*/

/*Hide Pop-Up menu but do not remove the image on the window*/
	pascal void ObscurePopUp (short MenuNumber);				/*Pop-Up Menu number							*/

/*Get an Pop-Up Menu item's text*/
	pascal void GetPopUpString (short MenuNumber,				/*Pop-Up Menu number							*/
									short ItemNumber,			/*Item number within the menu					*/
									Str255 MenuText);			/*Menu item's name								*/

/*Change the name of a Pop-Up Menu item*/
	pascal void RenamePopUp (short MenuNumber,					/*Pop-Up Menu number							*/
									short ItemNumber,			/*Item number within the menu					*/
									const Str255 MenuText);		/*Menu item's name								*/

/*Enable/disable a Pop-Up Menu or menu item*/
	pascal void EnablePopUp (short MenuNumber,					/*Pop-Up Menu number							*/
									short ItemNumber,			/*Item number within the menu (or 0)			*/
									Boolean EnabledFlag);		/*Enable the menu or item						*/

/*Determine if a Pop-Up Menu is enabled*/
	pascal Boolean PopUpIsEnabled (short MenuNumber				/*Pop-Up Menu number							*/
									);							/* = Is the menu enabled?						*/

/*Display/remove a Pop-Up Menu item's check mark*/
	pascal void CheckPopUp (short MenuNumber,					/*Pop-Up Menu number							*/
									short ItemNumber,			/*Item number within the menu					*/
									Boolean checked);			/*Place check mark beside the menu item			*/

/*Mark a Pop-Up Menu item with a specified character ( or , etc)*/
	pascal void PopUpMark (short MenuNumber,					/*Pop-Up Menu number							*/
									short ItemNumber,			/*Item number within the menu					*/
									char markChar);				/*Menu item's character							*/

/*Get a Pop-Up Menu item's "mark" character ( or , etc) which is optionally displayed at the item's left side*/
	pascal void GetPopUpMark (short MenuNumber,					/*Pop-Up Menu number							*/
									short ItemNumber,			/*Item number within the menu					*/
									char *markChar);			/*Menu item's character							*/

/*Specify an icon to be displayed by a Pop-Up Menu item*/
	pascal void PopUpIcon (short MenuNumber,					/*Pop-Up Menu number							*/
									short ItemNumber,			/*Item number within the menu					*/
									short IconSelector);		/*IconSelector + 256 = Icon ID number			*/

/*Get the specifier for the icon that is displayed by a Pop-Up Menu item*/
	pascal void GetPopUpIcon (short MenuNumber,					/*Pop-Up Menu number							*/
									short ItemNumber,			/*Item number within the menu					*/
									short *IconSelector);		/*IconSelector + 256 = Icon ID number			*/

/*Set the character style for a Pop-Up Menu item*/
	pascal void PopUpStyle (short MenuNumber,					/*Pop-Up Menu number							*/
									short ItemNumber,			/*Item number within the menu					*/
									Style theStyle);			/*Menu item's character style					*/

/*Determine the number of items in a Pop-Up Menu*/
	pascal short PopUpItemCount (short MenuNumber				/*Pop-Up Menu number							*/
									);							/* = Number of items in the menu				*/

/*Determine the selected item in a Pop-Up Menu*/
	pascal short GetPopUpSelection (short MenuNumber			/*Pop-Up Menu number							*/
									);							/* = Selected item in the menu					*/

/*Move a pop-up menu to a new location*/
	pascal void MovePopUp (short MenuNumber,					/*Pop-Up menu number							*/
									short toHoriz,				/*Horizontal position in local co-ordinates		*/
									short toVert);				/*Vertical position in local co-ordinates		*/

/*Move a pop-up menu's co-ordinates to a new location without moving the image*/
	pascal void OffsetPopUp (short MenuNumber,					/*Pop-Up menu number							*/
									short distHoriz,			/*Number of pixels to be offset (horiz/vert)	*/
									short distVert);			/*												*/

/*Change a pop-up menu's size*/
	pascal void SizePopUp (short MenuNumber,					/*Pop-Up menu number							*/
									short width);				/*New width in pixels							*/

/*Change a pop-up menu's co-ordinates (size and/or location)*/
	pascal void MoveSizePopUp (short MenuNumber,				/*Pop-Up menu number							*/
									short left,					/*Enclosing rectangle co-ordinates (local)		*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom);				/*												*/

/*Change a pop-up menu's co-ordinates (size and/or location,  co-ordinates specified as a 'rect') */
	pascal void MoveSizePopUpRect (short MenuNumber,			/*Pop-Up menu number							*/
									const Rect *Bounds);		/*Enclosing rectangle co-ordinates (local)		*/

/*Specify which sides of a pop-up menu are automatically moved when the window is resized*/
	pascal void AutoMoveSizePopUp (short MenuNumber,			/*Pop-Up menu number							*/
									Boolean left,				/*Menu's left side tracks window's right edge	*/
									Boolean top,				/*Menu's top & bottom track window's bottom edge*/
									Boolean right);				/*Menu's right side tracks window's right edge	*/



/*=============================================== C U R S O R S ===============================================	*/
/*Change the cursor shape*/
	pascal void CursorShape (short CursorType); 				/*Cursor type									*/

/*Reset the cursor to its appropriate shape depending on its location in the active window.*/
	pascal void ResetCursor(void);

/*Set the cursor animation sequence														[Developer Kit bonus]	*/
	pascal void SetCursorAnimation (short acurResID);			/*"acur" (cursor animation) resource ID			*/

/*Force cursor animation																[Developer Kit bonus]	*/
	pascal void AnimateCursor(void);
	
/*Create a new Cursor Table*/
	pascal void NewCursorTable (short CursorTable,				/*Cursor table number							*/
									short CursorType);			/*Cursor type									*/

/*Delete a Cursor Table*/
	pascal void DeleteCursorTable (short CursorTable);			/*Cursor table number							*/

/*Add a new Cursor Zone to a Cursor Table, or replace an existing Cursor Zone*/
	pascal void CursorZone (short CursorTable,					/*Cursor table number							*/
									short Zone,					/*Cursor zone number							*/
									short CursorType,			/*Cursor type									*/
									short left,					/*Cursor zone's co-ordinates (local)			*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom);				/*												*/						

/*Add a new Cursor Zone to a Cursor Table, or replace an existing Cursor Zone (co-ordinates specified as a "rect") */
	pascal void CursorZoneRect (short CursorTable,				/*Cursor table number							*/
									short Zone,					/*Cursor zone number							*/
									short CursorType,			/*Cursor type									*/
									const Rect *Bounds);		/*Cursor zone's co-ordinates (local)			*/

/*Add a new Cursor Zone to a Cursor Table, or replace an existing Cursor Zone (co-ordinates specified as a "region") */
	pascal void CursorZoneRgn (short CursorTable,				/*Cursor table number							*/
									short Zone,					/*Cursor zone number							*/
									short CursorType,			/*Cursor type									*/
									RgnHandle ZoneRgn);			/*Cursor zone's region (local)					*/

/*Indicate that the cursor shape may have to be recalculated due to manually altering Cursor Zone regions.		*/
	pascal void ChangedCursorZone(void);

/*Delete a Cursor Zone*/
	pascal void DeleteCursorZone (short CursorTable,			/*Cursor table number							*/
									short Zone);				/*Cursor zone number							*/

/*Get the co-ordinates of a specified Cursor Zone*/
	pascal void GetCursorZone (short CursorTable,				/*Cursor table number							*/
									short Zone,					/*Cursor zone number							*/
									Rect *Bounds);				/*Cursor zone's co-ordinates (local)			*/

/*Get a Cursor Zone's region*/
	pascal RgnHandle GetCursorZoneRgn (short CursorTable,		/*Cursor table number							*/
									short Zone					/*Cursor zone number							*/
									);							/* = Handle to Cursor region (local)			*/

/*Make the current window use a specified Cursor Table*/
	pascal void UseCursorTable (short CursorTable);				/*Cursor table number							*/

/*Find the cursor zone that contains a specified point*/
	pascal short FindCursorZone (Point thePoint					/*Location in window's local co-ordinates		*/
									);							/* = Cursor zone number containing the point	*/

/*Change the cursor shape for a Cursor Table or a Cursor Zone*/
	pascal void SetCursorZoneCurs (short CursorTable,			/*Cursor table number							*/
									short Zone,					/*Cursor zone number (0 = Cursor Table default)	*/
									short CursorType);			/*Cursor type									*/

/*Determine which Cursor Zone contains the cursor*/
	pascal void GetCurrentCursorZone (short *Window,			/*Window number									*/
									short *CursorTable,			/*Cursor table number							*/
									short *Zone);				/*Cursor zone number (0 = Cursor Table default)	*/

/*Enable/disable clicks on push-buttons when the watchCursor is displayed*/
	pascal void WatchCursorButtons (Boolean Allowed);			/*Can push-buttons be clicked when the			*/
																/*	watchCursor is displayed?					*/



/*=============================================== P O L L I N G ===============================================	*/
/*Tools Plus polling procedure*/
	pascal Boolean PollSystem (TPPollRecord *Poll				/*Polling record								*/
									);							/* = Did an event occurred?						*/

/*Set the number of ticks (1/60 sec) your application can wait until it receives a doNothing event.*/
	pascal void SetNullTime (long ActiveTime,					/*Duration active application					*/
									long SuspendedTime);		/*Duration suspended application				*/

/*Determine if "waiting for doNothing events" (timed doNothing events) is supported.*/
	pascal Boolean WaitAvail(void);								/*Is waiting between doNothing events supported?*/

/*Determine if the application is "suspended" (ie: this is not the active application)*/
	pascal Boolean ApplicationSuspended(void);					/* = Is the application suspended?				*/

/*Wait for subsequent clicks in a multiple click sequence?*/
	pascal void WaitForMultiClicks (Boolean WaitFlag);			/*Wait for subsequent events					*/

/*Clear the mouse's current click or drag (ie: discontinue the process, clear the event) */
	pascal void ResetMouseClicks(void);
	
/*Ignore the first mouse click of a multi-click sequence*/
	pascal void IgnoreFirstMouseClick(void);



/*========================================= C O L O R   D R A W I N G =========================================	*/
/*Determine if the Macintosh has color QuickDraw*/
	pascal Boolean HasColorQuickDraw(void);						/*Does the Mac have color QuickDraw				*/

/*Determine the number of logical screens (distinct screen depth and color/gray settings)*/
	pascal short NumberOfScreens(void);							/*Number of logical screens available			*/

/*Begin updating the specified logical screen*/
	pascal void BeginUpdateScreen (short TheScreen);			/*Logical screen number							*/

/*End updating the most recent logical screen*/
	pascal void EndUpdateScreen(void);

/*Determine the logical screen's depth*/
	pascal short ScreenDepth(void);								/*Screen depth in bits							*/

/*Determine if the logical screen is set to display in color*/
	pascal Boolean ScreenHasColors(void);						/*Is the screen set to display in color			*/

/*Determine if a rectangle is in a window's visible region.*/
	pascal Boolean RectIsVisible (const Rect *TheRect			/*Rectangle in window's local coordinates		*/
									);							/* = Is the rect in the window's visible region	*/

/*Determine if a known region is in a window's visible region.*/
	pascal Boolean RgnIsVisible (RgnHandle TheRgn				/*Region handle in window's local coordinates	*/
									);							/* = Is the rgn in the window's visible region	*/

/*Get the current port's foreground color*/
	pascal void GetFrontRGB (RGBColor *Color);					/*Current port's foreground RGB color			*/

/*Get the current port's background color*/
	pascal void GetBackRGB (RGBColor *Color);					/*Current port's background RGB color			*/

/*Set the current port's foreground color*/
	pascal void SetFrontRGB (const RGBColor *Color);			/*Current port's new foreground RGB color		*/

/*Set the current port's background color*/
	pascal void SetBackRGB (const RGBColor *Color);				/*Current port's new background RGB color		*/

/*Store a color's components in a color record*/
	pascal void SetRGB (RGBColor *Color,						/*RGB color record being set					*/
									unsigned short Red,			/*Color's red component							*/
									unsigned short Green,		/*Color's green component						*/
									unsigned short Blue);		/*Color's blue component						*/

/*Erase a rectangle using the window's backdrop color and invalidate it*/
	pascal void RedrawRect (const Rect *TheRect);				/*Rectangle in window's local coordinates		*/

/*Erase a region using the window's backdrop color and invalidate it*/
	pascal void RedrawRgn (RgnHandle TheRgn);					/*Region handle in window's local coordinates	*/

/*Calculate a "disabled" color*/
	pascal Boolean GetDimColor (const RGBColor *Front,			/*Foreground object's color (being disabled)	*/
									const RGBColor *Back,		/*Background color								*/
									RGBColor *DimColor			/*Foreground object's disabled color			*/
									);							/* = Is disabled color available (dither if not)*/

/*Set the foreground color to the system's highlight color, and the background color to white*/
	pascal void UseHiliteColor(void);

/*Set the text drawing mode for writing on the highlight color*/
	pascal void UseHiliteText(void);

/*Highlight or unhighlight a rectangle and set the text drawing mode for writing in the area*/
	pascal void HiliteRect (const Rect *TheRect,				/*Rectangle that is (un)highlighted				*/
									Boolean Hilite);			/*Is the rectangle's area highlighted			*/

/*Highlight or unhighlight a region and set the text drawing mode for writing in the area*/
	pascal void HiliteRgn (RgnHandle TheRgn,					/*Region that is (un)highlighted				*/
									Boolean Hilite);			/*Is the region's area highlighted				*/

/*Color equivalent to "PenNormal" routine*/
	pascal void PenColorNormal(void);

/*Color equivalent to "GetPenState" routine*/
	pascal void GetColorPenState (ColorPenState *ThePenState);	/*Pen settings									*/

/*Color equivalent to "SetPenState" routine*/
	pascal void SetColorPenState (const ColorPenState *ThePenState); /*Pen settings								*/



/*===================================== U S E R    N O T I F I C A T I O N ====================================	*/
/*Define the settings for notifying the user.*/
	pascal void SetNotification (short IconID,					/*"SICN" icon ID displayed during notification	*/
									short SoundID,				/*Sound ID that is played at notification		*/
									const Str255 Message,		/*Message displayed during notification			*/
									Boolean ResetAfterUse);		/*Revert settings to defaults after notification*/

/*If this application is inactive, inform user that this application needs attention.*/
	pascal Boolean PostNotification(void);						/*Was the user notified							*/



/*======================================== D Y N A M I C   A L E R T S ========================================	*/
/*Display a dynamic Alert Box and return the use's action*/
	pascal short AlertBox (short theIcon,						/*Icon ID number								*/
									const Str255 AlertText,		/*Alert's text									*/
									long AlertCode				/*Button setup code								*/
									);							/* = Button clicked by user						*/


/*Display a dynamic Alert Box (using temporary button names) and return the use's action*/
	pascal short AlertBox3 (short theIcon,						/*Icon ID number								*/
									const Str255 AlertText,		/*Alert's text									*/
									long AlertCode,				/*Button setup code								*/
									const Str255 But1,			/*Temporary names for buttons 1, 2 and 3		*/
									const Str255 But2,			/*												*/
									const Str255 But3			/*												*/
									);							/* = Button clicked by user						*/

/*Change a button name for the next use of the dynamic Alert Box*/
	pascal void AlertButtonName (short Button,					/*Button number from 1 to 9						*/
									const Str255 Title);		/*Button's title								*/

/*Enable or disable menus when a dynamic "Alert Box" is displayed*/
	pascal void AlertBoxMenus (Boolean EnableFlag);				/*Leave menus enabled when alert is shown		*/



/*============================  S T R #   S T R U C T U R E   M A I N T E N A N C E  ==========================	*/
/*Create a new Indexed String record (identical to 'STR#' resource)	*/
	pascal Handle NewIndexStringHandle (short NumberOfStrings	/*Number of strings in record					*/
									);							/* = Handle to Indexed String record			*/

/*Determine the number of strings in an Indexed String record*/
	pascal short CountIndexString (Handle hRec					/*Handle to Indexed String record				*/
									);							/* = Number of strings in the record			*/

/*Get a string from an Indexed String record*/
	pascal void GetIndexString (Handle hRec,					/*Handle to Indexed String record				*/
									short Index,				/*Element number being retrieved				*/
									Str255 Text);				/*String retrieved from specified index positon	*/

/*Save a string in an Indexed String record*/
	pascal void SetIndexString (Handle hRec,					/*Handle to Indexed String record				*/
									short Index,				/*Element number being updated					*/
									const Str255 Text);			/*New string value								*/

/*Insert a string into an Indexed String record*/
	pascal void InsertIndexString (Handle hRec,					/*Handle to Indexed String record				*/
									short Index,				/*Element number where new string is inserted	*/
									const Str255 Text);			/*Newly inserted string							*/

/*Delete a string from an Indexed String record*/
	pascal void DeleteIndexString (Handle hRec,					/*Handle to Indexed String record				*/
									short Index);				/*Element number where string is deleted		*/



/*==================== O f f   S c r e e n   B i t   M a p s   a n d   P i x e l   M a p s ====================	*/
/*Create an offscreen bitmap (or pixmap) and make it the current grafPtr*/
	pascal Boolean CreateBitMap (GrafPtr *newPort,				/*Returned pointer to new offscreen bitmap		*/
									GDHandle *hGDevice,			/*Returned handle to graphics device			*/
									const Rect *Bounds,			/*Bitmap's bounding rect, window's local co-ords*/
									short TypeOfMap				/*Type of bitmap created						*/
									);							/* = Was Bitmap successfully created?			*/

/*Destroy an offscreen bitmap (or pixMap)*/
	pascal void DestroyBitMap (GrafPtr oldOffscreen);			/*Pointer to old offscreen bitmap				*/

/*Convert a BitMap or PixMap to a region (works on all systems) */
	pascal OSErr BitMap2Region (RgnHandle Region,				/*Valid region handle							*/
									BitMap bMap					/*BitMap or 1-bit deep PixMap					*/
									);							/* = OS Error code								*/



/*========================================= M I S C E L L A N E O U S =========================================	*/
/*Draw a string in a specified rectangle*/
	pascal void StrInBox (short left, 							/*Enclosing view rectangle co-ordinates (local)	*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom,				/*												*/
									const Str255 Text,			/*String being displayed						*/
									long DispSpec,				/*Display specifications						*/
									short Just);				/*Justification: left,centre,right => 0,1,-1	*/

/*Draw a string in a specified rectangle (co-ordinates specified as a "rect") */
	pascal void StrInBoxRect (const Rect *Bounds,				/*Enclosing view rectangle co-ordinates (local)	*/
									const Str255 Text,			/*String being displayed						*/
									long DispSpec,				/*Display specifications						*/
									short Just);				/*Justification: left,centre,right => 0,1,-1	*/

/*Draw text in a specified rectangle*/
	pascal void TextInBox (short left, 							/*Enclosing view rectangle co-ordinates (local)	*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom,				/*												*/
									const Ptr TextPtr,			/*Pointer to text being displayed				*/
									short Length,				/*Number of characters being displayed			*/
									long DispSpec,				/*Display specifications						*/
									short Just);				/*Justification: left,centre,right => 0,1,-1	*/

/*Draw text in a specified rectangle (co-ordinates specified as a "rect") */
	pascal void TextInBoxRect (const Rect *Bounds,				/*Enclosing view rectangle co-ordinates (local)	*/
									const Ptr TextPtr,			/*Pointer to text being displayed				*/
									short Length,				/*Number of characters being displayed			*/
									long DispSpec,				/*Display specifications						*/
									short Just);				/*Justification: left,centre,right => 0,1,-1	*/

/*Draw a picture ('PICT' resource)*/
	pascal void DrawPict (short BaseID,							/*Base PICT ID number							*/
									short left,					/*Enclosing view rectangle co-ordinates (local)	*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom,				/*												*/
									long DispSpec);				/*Display specifications						*/

/*Draw a picture (co-ordinates specified as a "rect") */
	pascal void DrawPictRect (short BaseID,						/*Base PICT ID number							*/
									const Rect *Bounds,			/*Enclosing view rectangle co-ordinates (local)	*/
									long DispSpec);				/*Display specifications						*/

/*Draw a picture shifted within a rectangle*/
	pascal void DrawShiftPict (short BaseID,					/*Base PICT ID number							*/
									short left,					/*Enclosing view rectangle co-ordinates (local)	*/
									short top,					/*												*/
									short right,				/*												*/
									short bottom,				/*												*/
									short dh, short dv,			/*Number of pixels to be offset (horiz/vert)	*/
									long DispSpec);				/*Display specifications						*/

/*Draw a picture shifted within a rectangle (co-ordinates specified as a "rect") */
	pascal void DrawShiftPictRect (short BaseID,				/*Base PICT ID number							*/
									const Rect *Bounds,			/*Enclosing view rectangle co-ordinates (local)	*/
									short dh, short dv,			/*Number of pixels to be offset (horiz/vert)	*/
									long DispSpec);				/*Display specifications						*/

/*Determine the System file version*/
	pascal double SystemVersion(void);							/*System file version (eg 7.0.1 seen as 7.01)	*/

/*Draw an icon (ICON, ICN#, icl8, icl4, cicn, ics#, ics8, ics4,SICN)*/
	pascal void DrawIcon (short theIcon,						/*Icon ID number								*/
									short left,					/*Icon's top-left corner (local)				*/
									short top,					/*												*/
									Boolean EnabledFlag,		/*Enable the icon?								*/
									Boolean SelectedFlag);		/*Select the icon?								*/

/*Draw an SICN icon (srcCopy mode used) */
	pascal void DrawSICN (short theIcon,						/*SICN ID number								*/
									short left,					/*Icon's top-left corner, window's local co-ord.*/
									short top,					/*												*/
									short index);				/*Image number in SICN resource					*/

/*Draw an SICN icon (any copy mode) */
	pascal void DrawSICNmode (short theIcon,					/*SICN ID number								*/
									short left,					/*Icon's top-left corner, window's local co-ord.*/
									short top,					/*												*/
									short index,				/*Image number in SICN resource					*/
									short mode);				/*Copying mode (srcOr, srcCopy, etc.)			*/

/*Specify the default appearance for disabled icons*/
	pascal void DefaultIconLook (long IconSpec);				/*Appearance specifications						*/

/*Draw a standard Macintosh progress thermometer*/
	pascal void DrawThermometer (const Rect *DisplayRect,		/*Thermometer's co-ordinates (local)			*/
									long Value,					/*Current value									*/
									long Maximum);				/*Maximum value (progress = Value  Maximum)	*/

/*Draw "zoom" lines (expanding/collapsing rectangle)*/
	pascal void ZoomLines (const Rect *OldRect,					/*Starting rectangle (global co-ordinates)		*/
									const Rect *NewRect,		/*Ending rectangle (global co-ordinates)		*/
									short Zoom);				/*Zoom across, in, or out						*/

/*Play the System Error sound*/
	pascal void Beep(void);

/*Wait for a specified duration*/
	pascal void Wait (long ClockTicks);							/*Number of ticks (1/60th sec) to wait			*/

/*Synchronize to video (wait until vertical retrace occurs before continuing) */
	pascal void SynchToVideo(void);

/*Set all bytes in a record to zero (0)*/
	pascal void SetToZero (const void *RecPtr,					/*Address of (pointer to) record being zeroed	*/
									long RecSize);				/*Size of record in bytes						*/

/*Determine if two memory blocks contain equal data*/
	pascal Boolean EqualMem (const void *Ptr1,					/*Pointer to 1st memory block					*/
									const void *Ptr2,			/*Pointer to 2nd memory block					*/
									long BytesToCheck			/*Number of bytes being compared				*/
									);							/* = Are the two blocks equal?					*/

/*Determine the minimum value of 2 numbers*/
	pascal long min (long Val1, long Val2);

/*Determine the maximum value of 2 numbers*/
	pascal long max (long Val1, long Val2);

/*Get the Tools Plus version number*/
	pascal void GetToolsPlusVersion (Str255 Version);			/*Tools Plus version number returned			*/



/*===========================  M u l t i p l e   L a n g u a g e   S u p p o r t  =============================	*/
/*Select an STR# resource to replace Tools Plus text*/
	pascal void ToolsPlusLanguage (short ResID);				/*STR# resource containing replacement strings	*/










/*==================  C   S t r i n g s   I n   T o o l s   P l u s   P a r a m e t e r s  ====================	*/

#if TOOLSPLUS_ALLOWS_CSTRINGS

/*	The following prototypes are declared only if your application allows the use
 *	of C strings as parameters in Tools Plus routines.  These prototypes are for
 *	Tools Plus "glue" routines. They are identical to their mixed case
 *	equivalents (i.e., windowopen and WindowOpen) except that these routines
 *	accept C strings as parameters instead of Pascal strings. These routines are
 *	located in the ToolsPlus.c file. 
 */
void windowopen (short Window, short left, short top, short right, short bottom, const char *Title, long Spec, Boolean goAwayFlag, Boolean modalFlag);
void windowopenrect (short Window, const Rect *Bounds, const char *Title, long Spec, Boolean goAwayFlag, Boolean modalFlag);
void windowtitle (short Window, const char *Title);
void newbutton (short Button, short left, short top, short right, short bottom, const char *Title, long Spec, Boolean EnabledFlag, Boolean SelectedFlag);
void newbuttonrect (short Button, const Rect *Bounds, const char *Title, long Spec, Boolean EnabledFlag, Boolean SelectedFlag);
void buttontitle (short Button, const char *Title);
void geteditstring (char *EditString);
void getfieldstring (short Field, char *EditString);
void pasteintofield (short Field, const char *Text, Boolean Replace);
short newfieldfilter (const char *Chars, long FilterSpec);
void setlistboxtext (short ListBox, short LineNum, const char *Text);
void getlistboxtext (short ListBox, short LineNum, char *Text);
short searchlistbox (short ListBox, const char *Text);
void newpanel (short Panel, short left, short top, short right, short bottom, const char *Title, long Spec, short ShadowWidth);
void newpanelrect (short Panel, const Rect *Bounds, const char *Title, long Spec, short ShadowWidth);
void applemenu (const char *AboutName);
void menu (short MenuNumber, short ItemNumber, Boolean EnabledFlag, const char *MenuText);
void insertmenuitm (short MenuNumber, short ItemNumber, Boolean EnabledFlag, const char *MenuText);
void getmenustring (short MenuNumber, short ItemNumber, char *MenuText);
void renameitem (short MenuNumber, short ItemNumber, const char *MenuText);
void newpopup (short MenuNumber, short left, short top, short right, short bottom, const char *MenuTitle, long Spec, Boolean EnabledFlag);
void newpopuprect (short MenuNumber, const Rect *Bounds, const char *MenuTitle, long Spec, Boolean EnabledFlag);
void popupmenu (short MenuNumber, short ItemNumber, Boolean EnabledFlag, const char *MenuText);
void insertpopupitem (short MenuNumber, short ItemNumber, Boolean EnabledFlag, const char *MenuText);
void getpopupstring (short MenuNumber, short ItemNumber, char *MenuText);
void renamepopup (short MenuNumber, short ItemNumber, const char *MenuText);
void setnotification (short IconID, short SoundID, const char *Message, Boolean ResetAfterUse);
short alertbox (short theIcon, const char *AlertText, long AlertCode);
short alertbox3 (short theIcon, const char *AlertText, long AlertCode, const char *But1, const char *But2, const char *But3);
void alertbuttonname (short Button, const char *Title);
void getindexstring (Handle hRec, short Index, char *Text);
void setindexstring (Handle hRec, short Index, const char *Text);
void insertindexstring (Handle hRec, short Index, const char *Text);
void strinbox (short left, short top, short right, short bottom, const char *Text, long DispSpec, short Just);
void strinboxrect (const Rect *Bounds, const char *Text, long DispSpec, short Just);
void gettoolsplusversion (char *Version);


#if TOOLSPLUS_USES_ONLY_CSTRINGS

/*	The following #defines are declared only if your application uses _only_
 *	C strings as parameters in Tools Plus routines. They allow you to use
 *	standard Tools Plus routine names and they remap the required routine to
 *	use "glue" routines where required.
 */

#define	WindowOpen(Window,left,top,right,bottom,Title,Spec,goAwayFlag,modalFlag)	windowopen(Window,left,top,right,bottom,Title,Spec,goAwayFlag,modalFlag)
#define	WindowOpenRect(Window,Bounds,Title,Spec,goAwayFlag,modalFlag)				windowopenrect(Window,Bounds,Title,Spec,goAwayFlag,modalFlag)
#define	WindowTitle(Window,Title)													windowtitle(Window,Title)
#define	NewButton(Button,left,top,right,bottom,Title,Spec,EnabledFlag,SelectedFlag)	newbutton(Button,left,top,right,bottom,Title,Spec,EnabledFlag,SelectedFlag)
#define	NewButtonRect(Button,Bounds,Title,Spec,EnabledFlag,SelectedFlag)			newbuttonrect(Button,Bounds,Title,Spec,EnabledFlag,SelectedFlag)
#define	ButtonTitle(Button,Title)													buttontitle(Button,Title)
#define	GetEditString(EditString)													geteditstring(EditString)
#define	GetFieldString(Field,EditString)											getfieldstring(Field,EditString)
#define	PasteIntoField(Field,Text,Replace)											pasteintofield(Field,Text,Replace)
#define	NewFieldFilter(Chars,FilterSpec)											newfieldfilter(Chars,FilterSpec)
#define	SetListBoxText(ListBox,LineNum,Text)										setlistboxtext(ListBox,LineNum,Text)
#define	GetListBoxText(ListBox,LineNum,Text)										getlistboxtext(ListBox,LineNum,Text)
#define	SearchListBox(ListBox,Text)													searchlistbox(ListBox,Text)
#define	NewPanel(Panel,left,top,right,bottom,Title,Spec,ShadowWidth)				newpanel(Panel,left,top,right,bottom,Title,Spec,ShadowWidth)
#define	NewPanelRect(Panel,Bounds,Title,Spec,ShadowWidth)							newpanelrect(Panel,Bounds,Title,Spec,ShadowWidth)
#define	AppleMenu(AboutName)														applemenu(AboutName)
#define	Menu(MenuNumber,ItemNumber,EnabledFlag,MenuText)							menu(MenuNumber,ItemNumber,EnabledFlag,MenuText)
#define	InsertMenuItm(MenuNumber,ItemNumber,EnabledFlag,MenuText)					insertmenuitm(MenuNumber,ItemNumber,EnabledFlag,MenuText)
#define	GetMenuString(MenuNumber,ItemNumber,MenuText)								getmenustring(MenuNumber,ItemNumber,MenuText)
#define	RenameItem(MenuNumber,ItemNumber,MenuText)									renameitem(MenuNumber,ItemNumber,MenuText)
#define	NewPopUp(MenuNumber,left,top,right,bottom,MenuTitle,Spec,EnabledFlag)		newpopup(MenuNumber,left,top,right,bottom,MenuTitle,Spec,EnabledFlag)
#define	NewPopUpRect(MenuNumber,Bounds,MenuTitle,Spec,EnabledFlag)					newpopuprect(MenuNumber,Bounds,MenuTitle,Spec,EnabledFlag)
#define	PopUpMenu(MenuNumber,ItemNumber,EnabledFlag,MenuText)						popupmenu(MenuNumber,ItemNumber,EnabledFlag,MenuText)
#define	InsertPopUpItem(MenuNumber,ItemNumber,EnabledFlag,MenuText)					insertpopupitem(MenuNumber,ItemNumber,EnabledFlag,MenuText)
#define	GetPopUpString(MenuNumber,ItemNumber,MenuText)								getpopupstring(MenuNumber,ItemNumber,MenuText)
#define	RenamePopUp(MenuNumber,ItemNumber,MenuText)									renamepopup(MenuNumber,ItemNumber,MenuText)
#define	SetNotification(IconID,SoundID,Message,ResetAfterUse)						setnotification(IconID,SoundID,Message,ResetAfterUse)
#define	AlertBox(theIcon,AlertText,AlertCode)										alertbox(theIcon,AlertText,AlertCode)
#define	AlertBox3(theIcon,AlertText,AlertCode,But1,But2,But3)						alertbox3(theIcon,AlertText,AlertCode,But1,But2,But3)
#define	AlertButtonName(Button,Title)												alertbuttonname(Button,Title)
#define	GetIndexString(hRec,Index,Text)												getindexstring(hRec,Index,Text)
#define	SetIndexString(hRec,Index,Text)												setindexstring(hRec,Index,Text)
#define	InsertIndexString(hRec,Index,Text)											insertindexstring(hRec,Index,Text)
#define	StrInBox(left,top,right,bottom,Text,DispSpec,Just)							strinbox(left,top,right,bottom,Text,DispSpec,Just)
#define	StrInBoxRect(Bounds,Text,DispSpec,Just)										strinboxrect(Bounds,Text,DispSpec,Just)
#define	GetToolsPlusVersion(Version)												gettoolsplusversion(Version)

#endif // C strings only in Tools Plus routines

#endif // C strings allowed in Tools Plus routines




#ifdef __cplusplus
}
#endif


#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=reset
#endif


#endif /* __ToolsPlus__ */