//	Tools Plus Tutorial -- Buttons and Panels



 #include "ToolsPlus.h"

 
 #define VendorWindow		1		// Window constants (just to make the code readable)
 #define DebuggerWindow	2

 #define OkButton				255	// Button constants
 #define CancelButton		254

 #define checkSymFile		1
 #define checkFullPath	2
 #define checkLinkMap		3
 #define checkA6				4
 #define checkDebugger	5

 #define typeAle				1
 #define typeDraft			2
 #define typeLager			3
 #define typeLite				4
 #define typeWater			5
 #define levelHigh			10
 #define levelMedium		11
 #define levelLow				12
 
 
 
 TPPollRecord		Poll;					// Polling record to retrieve event information
 Boolean				ExitTheDemo;	// Should the demo terminate?


 void ApplicationInitialization (void);
 void ProcessMenuSelection (void);






 //	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-
 void main(void)
 {
	InitGraf(&qd.thePort);
	InitFonts();
	InitWindows();
	InitMenus();
	TEInit();
	InitDialogs(0L);


	if (!InitToolsPlus(10, 2, initTE32KBuffer, initUseColor))
		ExitToShell();

	ApplicationInitialization();

	while (!ExitTheDemo)					// Main Event Loop
		{
		if (PollSystem(&Poll))			// If an event is available, process the event
			{
			switch (Poll.What)
				{
				case doMenu:
					ProcessMenuSelection();
					break;


				case doChgWindow:	// User clicked an inactive window
					ActivateWindow(Poll.Window);
					break;


				case doGoAway:		// User clicked a window's close box
					WindowClose(Poll.Window);
					break;


				case doButton:		// User clicked a button
					// Subsequent action takes place on this window (current grafPort)
					CurrentWindow(Poll.Window);
					if (Poll.Window == VendorWindow)	// Button clicked in "Vendor" window
						{
						switch (Poll.Button.Num)
							{
							case OkButton: case CancelButton: 
								WindowClose(VendorWindow);
								break;
							default:
								SelectButton(Poll.Button.Num, selected);
								break;
							}
						}
 					else	// Button clicked in the "Debugger" window
 						{
						switch (Poll.Button.Num)
							{
							case checkSymFile: case checkFullPath: case checkLinkMap:
							case checkA6: case checkDebugger:
								SelectButton(Poll.Button.Num, !ButtonIsSelected(Poll.Button.Num));
								if (Poll.Button.Num == checkSymFile)
									{
									// "Check full path" box is available only when
									// "Generate SYM File" box is on
									EnableButton(checkFullPath, ButtonIsSelected(checkSymFile));
									if (!ButtonIsEnabled(checkFullPath))
										SelectButton(checkFullPath, false);
									}
								break;
									
							case OkButton: case CancelButton: 
								WindowClose(DebuggerWindow);
								break;
							}
 						}
 					break;


				case doRefresh: case doPictButton: case doKeyDown:
				case doAutoKey: case doClickField: case doScrollBar:
				case doListBox: case doPopUpMenu:	case doClick:
					break;					// Other core events we're ignoring in this app


				default:					// All other events are ignored
					break;
				}
			}
		}
 }



 //	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-
 void ApplicationInitialization (void)
	{
	//	Do all the application setup before you start polling for events

	// Create an Apple menu with an 'About' item
	AppleMenu("\pAbout My App");

	// Create the standard File and Edit menus
	Menu(mFileMenu, 0, enabled, "\pFile");
	Menu(mFileMenu, 1, disabled, "\pNew/N");
	Menu(mFileMenu, 2, disabled, "\pOpen/O");
	Menu(mFileMenu, 3, disabled, "\pClose/W");
	Menu(mFileMenu, 4, disabled, mDividingLine);
	Menu(mFileMenu, 5, enabled, "\pQuit/Q");

	Menu(mEditMenu, 0, enabled, "\pEdit");
	Menu(mEditMenu, 1, disabled, "\pUndo/Z");
	Menu(mEditMenu, 2, disabled, mDividingLine);
	Menu(mEditMenu, 3, disabled, "\pCut/X");
	Menu(mEditMenu, 4, disabled, "\pCopy/C");
	Menu(mEditMenu, 5, disabled, "\pPaste/V");
	Menu(mEditMenu, 6, disabled, "\pClear");
	Menu(mEditMenu, 7, disabled, mDividingLine);
	Menu(mEditMenu, 8, disabled, "\pShow Clipboard");


	// Create the "Vendor" window and populate it
	WindowOpen(VendorWindow, 0, 0, 250, 150, "\pVendor", noGrowDocProc + wTile, GoAway, NotModal);
	TextFont(geneva);
	TextSize(9);
	NewPanel(1, 15, 18, 85, 112, "\pType:", panGroupBox, 0);
	NewButton(typeAle, 25, 30, 60, 42, "\pAle", radioButProc + bUseWFont, enabled, selected);
	NewButton(typeDraft, 25, 45, 70, 57, "\pDraft", radioButProc + bUseWFont, enabled, notSelected);
	NewButton(typeLager, 25, 60, 70, 72, "\pLager", radioButProc + bUseWFont, enabled, notSelected);
	NewButton(typeLite, 25, 75, 62, 87, "\pLite", radioButProc + bUseWFont, enabled, notSelected);
	NewButton(typeWater, 25, 90, 70, 102, "\pWater", radioButProc + bUseWFont, enabled, notSelected);

	NewPanel(2, 130, 18, 220, 85, "\pLevel:", panGroupBox, 0);
	NewButton(levelHigh, 140, 29, 190, 43, "\pHigh", radioButProc, enabled, notSelected);
	NewButton(levelMedium, 140, 46, 214, 60, "\pMedium", radioButProc, enabled, selected);
	NewButton(levelLow, 140, 63, 188, 77, "\pLow", radioButProc, enabled, notSelected);

	NewButton(CancelButton, 110, 110, 167, 130, "\pCancel", pushButProc, enabled, notSelected);
	NewButton(OkButton, 185, 110, 235, 130, "\pOk", pushButProc + bDefault, enabled, notSelected);


	// Create the "Debugger" window and populate it
	WindowOpen(DebuggerWindow, 0, 0, 250, 150, "\pDebugger", noGrowDocProc + wTile, GoAway, NotModal);
	NewButton(checkSymFile, 35, 10, 160, 26, "\pCreate SYM File", checkBoxProc, enabled, notSelected);
	NewButton(checkFullPath, 53, 26, 208, 42, "\pFull Path in SYM File", checkBoxProc, disabled, notSelected);
	NewButton(checkLinkMap, 35, 42, 180, 58, "\pGenerate Link Map", checkBoxProc, enabled, notSelected);
	NewButton(checkA6, 35, 58, 230, 74, "\pGenerate A6 Stack Frames", checkBoxProc, enabled, notSelected);
	NewButton(checkDebugger, 35, 74, 200, 90, "\pThe Debugger Aware", checkBoxProc, enabled, notSelected);

	NewButton(CancelButton, 110, 110, 167, 130, "\pCancel", pushButProc, enabled, notSelected);
	NewButton(OkButton, 185, 110, 235, 130, "\pOk", pushButProc + bDefault, enabled, notSelected);


	ExitTheDemo = false;
	}



 //	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-
 void ProcessMenuSelection (void)
	{
 	#define		NewItem		1
 	#define		OpenItem	2
 	#define		CloseItem	3
 	#define		QuitItem	5

	short			theButton;


	switch (Poll.Menu.Num)
		{
		case mAppleMenu:	// Apple menu's 'About' item
			theButton = AlertBox(NoIcon, "\pThis is my applications about box.  (Click to close)", NoButtonAlert);
			break;
			
		case mFileMenu:
			switch (Poll.Menu.Item)
				{
				case NewItem:
					break;
				case OpenItem:
					break;
				case CloseItem:
					break;
				case QuitItem:
					ExitTheDemo = true;
					break;
				}
		}

	MenuHilite(0);	// Turn off highlighted menu
	}