//	Tools Plus Tutorial -- List Boxes




 #include "ToolsPlus.h"



 #define LeftList			1				// Constants to make code more readable
 #define RightList		2

 #define bMove				1
 #define bRemove			2
 #define DoneButton		255

 #define LeftToRight	1
 #define RightToLeft	-1



 TPPollRecord		Poll;					// Polling record to retrieve event information
 Boolean				ExitTheDemo;	// Should the demo terminate?
 short          Direction;		// Direction in which lines are moved (left-to-right
 															//	or right-to-left)



 void ApplicationInitialization (void);
 void ActionInWindow (void);






 //	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-
 void main(void)
 {
	InitGraf(&qd.thePort);
	InitFonts();
	InitWindows();
	InitMenus();
	TEInit();
	InitDialogs(0L);


	if (!InitToolsPlus(10, 1, initTE32KBuffer, initUseColor))
		ExitToShell();

	ApplicationInitialization();

	while (!ExitTheDemo)					//Main Event Loop
		if (PollSystem(&Poll))			//If an event is available, process the event
			if ((Poll.What == doListBox) || (Poll.What == doButton))	// User clicked something in this window
				ActionInWindow();

	// All other events are ignored
 }



 //	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-
 void ApplicationInitialization (void)
	{
	//	Do all the application setup before you start polling for events

 	#define		DemoWindow1		1



	WindowOpen(DemoWindow1, 0, 0, 440, 130, "\p", dBoxProc + wCenter, NoGoAway, Modal);

	// Create left list box, making it exactly 6 lines high using Chicago 12pt
	TextFont(systemFont);
	TextSize(12);
	NewListBox(LeftList, 15, 15, 145, -6, lOnlyOne);

	// Create left list box, making it exactly 8 lines high using Geneva 9pt
	TextFont(geneva);
	TextSize(9);
	NewListBox(RightList, 280, 15, 410, -8, lOnlyOne);

	// Create the buttons used to control these lists
	NewButton(bMove, 175, 20, 265, 40, "\pMove", pushButProc, disabled, notSelected);
	NewButton(bRemove, 175, 50, 265, 70, "\pRemove", pushButProc, disabled, notSelected);
	NewButton(DoneButton, 185, 92, 255, 112, "\pDone", pushButProc, enabled, notSelected);


	// Populate the left list with the names of all the fonts
  ResNamesToListBox(LeftList, 1, 'FONT');

	Direction = none;
	ExitTheDemo = false;
	}
	


 //	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-
 void ActionInWindow (void)
	{
	short			SourceList, TargetList;	// Source and target list when moving lines
	short			SourceLine, TargetLine;	// Line number in source and target list
	Str255		FontName;


	CurrentWindow(1);		// Subsequent actions affect window #1 (our only window)
	switch (Poll.What)
		{
		case doListBox: 
			if (GetListBoxLines(Poll.ListBox.Num, 1) == none)	// If an empty line was clicked
				{		// Nothing selected, so disable the buttons and deselect lines in both lists
				Direction = none;
				ButtonTitle(bMove, "\pMove");
				EnableButton(bMove, off);
				EnableButton(bRemove, off);
				SetListBoxLine(LeftList, max(1, GetListBoxLines(LeftList, 1)), off);
				SetListBoxLine(RightList, max(1, GetListBoxLines(RightList, 1)), off);
				}
			else
				{		// If a non-empty line was clicked in the list box
				switch (Poll.ListBox.Num)
					{
					case LeftList: 
						Direction = LeftToRight;
						ButtonTitle(bMove, "\p>> Move >>");
						// Turn off the line in the other list (if it has one selected)
						SetListBoxLine(RightList, max(1, GetListBoxLines(RightList, 1)), off);
						break;

					case RightList: 
						Direction = RightToLeft;
						ButtonTitle(bMove, "\p<< Move <<");
						// Turn off the line in the other list (if it has one selected)
						SetListBoxLine(LeftList, max(1, GetListBoxLines(LeftList, 1)), off);
						break;
					}
					EnableButton(bMove, on);
					EnableButton(bRemove, on);
				}
			break;

		case doButton: 
			switch (Poll.Button.Num)
				{
				case bMove:		// Move line from source list to target list
					if (Direction == LeftToRight)
						{
						SourceList = LeftList;
						TargetList = RightList;
						ButtonTitle(bMove, "\p<< Move <<");
						}
					else
						{
						SourceList = RightList;
						TargetList = LeftList;
						ButtonTitle(bMove, "\p>> Move >>");
						}
					SourceLine = GetListBoxLines(SourceList, 1);			// Find selected line in source list
					GetListBoxText(SourceList, SourceLine, FontName);	// Get selected line's text
					DeleteListBoxLine(SourceList, SourceLine);				// Delete line in source list

					TargetLine = SearchListBox(TargetList, FontName);	// Where should this name go in target list?
					InsertListBoxLine(TargetList, TargetLine);				// Insert an empty line
					SetListBoxText(TargetList, TargetLine, FontName);	// Put font name into empty line
					SetListBoxLine(TargetList, TargetLine, on);				// Select line in target list
					Direction = -Direction;														// Change direction of movement
					break;

				case bRemove:	// Remove the selected line
					if (Direction == LeftToRight)
						SourceList = LeftList;
					else
						SourceList = RightList;
					DeleteListBoxLine(SourceList, GetListBoxLines(SourceList, 1));
					Direction = none;
					ButtonTitle(bMove, "\pMove");
					EnableButton(bMove, off);
					EnableButton(bRemove, off);
					break;

				case DoneButton:		// We're done, quit the application
					ExitTheDemo = true;
					break;
				}
				break;
		}
	}
