{	Tools Plus Tutorial	- -	List Boxes	}

{	NOTE:	}
{	The MWERKS compiler directived ($IFC MWERKS) indicates code that is compiled only by	}
{	the CodeWarrior compiler.  THINK Pascal and Metrowerks CodeWarrior Pascal have	}
{	_slight_ differences, and this compiler directive lets you use one source for both compilers.	}
{	You can remove the code that does not pertain to your compiler.	}


program Tutorial;
	uses
{$IFC MWERKS}
		Dialogs, Fonts, Resources, Processes, SegLoad, TextEdit, ToolsPlus, Windows;
{$ELSEC}
		ToolsPlus;
{$ENDC}


	const
	{Constants to make code more readable}
		LeftList = 1;
		RightList = 2;

		bMove = 1;
		bRemove = 2;
		DoneButton = 255;

		LeftToRight = 1;
		RightToLeft = -1;

	var
		Poll: TPPollRecord;			{Polling record to retrieve event information}
		ExitTheDemo: boolean;		{Should the demo terminate?}
		Direction: integer;			{Direction in which lines are moved (left-to-right or right-to-left) }



{	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	}
	procedure ApplicationInitialization;
		const
			DemoWindow1 = 1;

	begin
	{	Do all the application setup before you start polling for events	}

		WindowOpen(DemoWindow1, 0, 0, 440, 130, '', dBoxProc + wCenter, NoGoAway, Modal);

	{ Create left list box, making it exactly 6 lines high using Chicago 12pt}
		TextFont(systemFont);
		TextSize(12);
		NewListBox(LeftList, 15, 15, 145, -6, lOnlyOne);

	{ Create left list box, making it exactly 8 lines high using Geneva 9pt}
		TextFont(geneva);
		TextSize(9);
		NewListBox(RightList, 280, 15, 410, -8, lOnlyOne);

	{ Create the buttons used to control these lists	}
		NewButton(bMove, 175, 20, 265, 40, 'Move', pushButProc, disabled, notSelected);
		NewButton(bRemove, 175, 50, 265, 70, 'Remove', pushButProc, disabled, notSelected);
		NewButton(DoneButton, 185, 92, 255, 112, 'Done', pushButProc, enabled, notSelected);

	{ Populate the left list with the names of all the fonts}
		ResNamesToListBox(LeftList, 1, 'FONT');

		Direction := none;
		ExitTheDemo := false;
	end;


{	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	}
	procedure ActionInWindow;
		var
			SourceList, TargetList: integer;	{Source and target list when moving lines}
			SourceLine, TargetLine: integer;	{Line number in source and target list}
			FontName: Str255;
	begin
		CurrentWindow(1);	{Subsequent actions affect window #1 (our only window)	}
		case Poll.What of

			doListBox: 
				if GetListBoxLines(Poll.ListBox.Num, 1) = none then	{If an empty line was clicked}
					begin	{Nothing selected, so disable the buttons and deselect lines in both lists}
						Direction := none;
						ButtonTitle(bMove, 'Move');
						EnableButton(bMove, off);
						EnableButton(bRemove, off);
						SetListBoxLine(LeftList, max(1, GetListBoxLines(LeftList, 1)), off);
						SetListBoxLine(RightList, max(1, GetListBoxLines(RightList, 1)), off);
					end
				else
					begin	{If a non-empty line was clicked in the list box}
						case Poll.ListBox.Num of
							LeftList: 
								begin
									Direction := LeftToRight;
									ButtonTitle(bMove, '>> Move >>');
					{ Turn off the line in the other list (if it has one selected)	}
									SetListBoxLine(RightList, max(1, GetListBoxLines(RightList, 1)), off);
								end;

							RightList: 
								begin
									Direction := RightToLeft;
									ButtonTitle(bMove, '<< Move <<');
					{ Turn off the line in the other list (if it has one selected)	}
									SetListBoxLine(LeftList, max(1, GetListBoxLines(LeftList, 1)), off);
								end
						end;
						EnableButton(bMove, on);
						EnableButton(bRemove, on);
					end;


			doButton: 
				case Poll.Button.Num of
					bMove: 	{Move line from source list to target list}
						begin
							if Direction = LeftToRight then
								begin
									SourceList := LeftList;
									TargetList := RightList;
									ButtonTitle(bMove, '<< Move <<');
								end
							else
								begin
									SourceList := RightList;
									TargetList := LeftList;
									ButtonTitle(bMove, '>> Move >>');
								end;
							SourceLine := GetListBoxLines(SourceList, 1);		{Find selected line in source list}
							GetListBoxText(SourceList, SourceLine, FontName);	{Get selected line's text}
							DeleteListBoxLine(SourceList, SourceLine);			{Delete line in source list}

							TargetLine := SearchListBox(TargetList, FontName);	{Where should this name go in target list?}
							InsertListBoxLine(TargetList, TargetLine);			{Insert an empty line}
							SetListBoxText(TargetList, TargetLine, FontName);	{Put font name into empty line}
							SetListBoxLine(TargetList, TargetLine, on);			{Select line in target list}
							Direction := -Direction;								{Change direction of movement}
						end;

					bRemove: 	{Remove the selected line}
						begin
							if Direction = LeftToRight then
								SourceList := LeftList
							else
								SourceList := RightList;
							DeleteListBoxLine(SourceList, GetListBoxLines(SourceList, 1));
							Direction := none;
							ButtonTitle(bMove, 'Move');
							EnableButton(bMove, off);
							EnableButton(bRemove, off);
						end;

					DoneButton: 	{We're done, quit the application}
						ExitTheDemo := true;
				end

		end
	end;


{	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	}
begin
{$IFC MWERKS}
{Toolbox initialization - - Done automatically by THINK Pascal}
	InitGraf(@qd.thePort);
	InitFonts;
	InitWindows;
	InitMenus;
	TEInit;
	InitDialogs(nil);
{$ENDC}

	if not InitToolsPlus(10, 1, initTE32KBuffer, initUseColor) then
		ExitToShell;

	ApplicationInitialization;

	while not ExitTheDemo do	{Main Event Loop}
		if PollSystem(Poll) then	{If an event is available, process the event}
			if (Poll.What = doListBox) or (Poll.What = doButton) then	{User clicked something in this window}
				ActionInWindow;

	{All other events are ignored}
end.