{	Tools Plus Tutorial	- -	Scrolling a field list	}

{	NOTE:	}
{	The MWERKS compiler directived ($IFC MWERKS) indicates code that is compiled only by	}
{	the CodeWarrior compiler.  THINK Pascal and Metrowerks CodeWarrior Pascal have	}
{	_slight_ differences, and this compiler directive lets you use one source for both compilers.	}
{	You can remove the code that does not pertain to your compiler.	}


program Tutorial;
	uses
{$IFC MWERKS}
		Dialogs, Fonts, Processes, SegLoad, TextEdit, TextUtils, ToolsPlus, Windows;
{$ELSEC}
		ToolsPlus;
{$ENDC}

	const
		fieldHeight = 12;	{Field's height}
		offsetPerRow = 13;	{Number of pixels eash row is offset}

		bCancel = 510;		{Cancel and OK buttons}
		bOK = 511;



	var
		Poll: TPPollRecord;			{Polling record to retrieve event information}
		theScrollRect: rect;			{Scrollable area}

		theRow: integer;			{Row number}
		theColumn: integer;			{Column number}
		fieldNumber: integer;		{Calculated field number}

		fieldStr: array[1..100, 1..4] of StringHandle;	{Contents of each field}

		prevScrollBarValue: integer;	{Scroll bar's value before & after user changed it}
		newScrollBarValue: integer;

		updateRgn: RgnHandle;		{Region exposed by scrolling (ignored)}
		ExitTheDemo: boolean;		{Should the demo terminate?}



{	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	}
	procedure DrawGridLines;
		var
			lineColor: RGBColor;
			theRow: integer;
	begin
	{	These 'color' routines are safe on Macs without Color QuickDraw	}
		SetRGB(lineColor, 32896, 32896, 32896);
		SetFrontRGB(lineColor);

		MoveTo(70, 20);	{Draw the 3 vertical lines}
		LineTo(70, 148);
		MoveTo(150, 20);
		LineTo(150, 148);
		MoveTo(300, 20);
		LineTo(300, 148);

	{	Draw a horizontal line beneath each row except the bottom one	}
		for theRow := 1 to 9 do
			begin
				MoveTo(21, 19 + (theRow * offsetPerRow));
				Line(338, 0);
			end
	end;





{	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	}
	procedure ScrollTheGrid;
		var
			vDist: integer;		{Vertical distance from top of window}

			theRow: integer;		{Row number}
			theColumn: integer;	{Column number}

			scrolledRows: integer;			{Number of rows scrolled}
			scrolledPixels: integer;			{Number of pixels the icons were moved}

			startRow, endRow: integer;		{First and last row being processed}
	begin
	{	Scroll the IMAGE of the fields and redraw the grid	}
		scrolledRows := prevScrollBarValue - newScrollBarValue;
		scrolledPixels := scrolledRows * offsetPerRow;
		ScrollRect(theScrollRect, 0, scrolledPixels, updateRgn);
		DrawGridLines;



	{	#1:	Delete obsolete fields (their data is still in the array of handles)	}
		if scrolledRows < 0 then	{	Scroll Up: Delete lines scrolled off the top of the list	}
			begin
				startRow := prevScrollBarValue;
				endRow := min(prevScrollBarValue + 9, newScrollBarValue - 1);
			end
		else	{	Scroll Down: Delete lines scrolled off the bottom of the list	}
			begin
				startRow := max(newScrollBarValue + 10, prevScrollBarValue);
				endRow := prevScrollBarValue + 9;
			end;
		for theRow := startRow to endRow do
			for theColumn := 1 to 4 do
				KillField(theRow * 10 + theColumn);



	{	#2: Shift co-ordinates for the remaining fields	}
		for theRow := prevScrollBarValue to prevScrollBarValue + 9 do
			for theColumn := 1 to 4 do
				OffsetField(theRow * 10 + theColumn, 0, scrolledPixels);



	{	#3:	Create new fields that are now appearing in the grid	}
		if scrolledRows < 0 then	{	Scroll Up: Add fields to the bottom of the list	}
			begin
				startRow := newScrollBarValue + 10 - min(-scrolledRows, 10);
				endRow := newScrollBarValue + 9;
			end
		else	{	Scroll Down: Add fields to the top of the list	}
			begin
				startRow := newScrollBarValue;
				endRow := startRow + min(scrolledRows, 10) - 1;
			end;
		TextFont(geneva);		{Fields are drawn using Geneva 9pt. }
		TextSize(9);
		for theRow := startRow to endRow do
			begin
				vDist := 20 + ((theRow - newScrollBarValue) * offsetPerRow);
				fieldNumber := theRow * 10;

		{	Our fields automatically shrink the handle down to match the amount of text in the field.	}
		{	Before we hand the handle to the field, we blow it up to the maxium size (255 chars plus	}
		{	length byte or null terminator). The field then knows that the handle's _maximum_ size.	}
				for theColumn := 1 to 4 do
					SetHandleSize(handle(fieldStr[theRow, theColumn]), 256);

		{Create the 4 columns in this row (4 fields)}
				NewField(fieldNumber + 1, 23, vDist, 68, vDist + fieldHeight, handle(fieldStr[theRow, 1]), teNoBoxNoCR + teResizeHdl, teJustLeft);
				NewField(fieldNumber + 2, 73, vDist, 148, vDist + fieldHeight, handle(fieldStr[theRow, 2]), teNoBoxNoCR + teResizeHdl, teJustLeft);
				NewField(fieldNumber + 3, 153, vDist, 298, vDist + fieldHeight, handle(fieldStr[theRow, 3]), teNoBoxNoCR + teResizeHdl, teJustLeft);
				NewField(fieldNumber + 4, 303, vDist, 357, vDist + fieldHeight, handle(fieldStr[theRow, 4]), teNoBoxNoCR + teResizeHdl, teJustLeft);
			end;




		prevScrollBarValue := newScrollBarValue;
	end;





{	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	}
	procedure ApplicationInitialization;
		const
			StdWindow1 = 1;

		var
			theRow: integer;		{Row number}
			theColumn: integer;	{Column number}

			rowStr, colStr: Str255;	{Row number and column number, expressed as a string}
			theFieldStr: Str255;		{Field's contents (initial value)}
	begin
		AppleMenu('');
		Menu(mFileMenu, 0, enabled, 'File');
		Menu(mFileMenu, 1, enabled, 'Quit/Q');
		Menu(mEditMenu, 0, enabled, 'Edit');
		Menu(mEditMenu, 1, disabled, 'Undo/Z');
		Menu(mEditMenu, 2, disabled, mDividingLine);
		Menu(mEditMenu, 3, disabled, 'Cut/X');
		Menu(mEditMenu, 4, disabled, 'Copy/C');
		Menu(mEditMenu, 5, disabled, 'Paste/V');
		Menu(mEditMenu, 6, disabled, 'Clear');
		Menu(mEditMenu, 7, disabled, mDividingLine);
		Menu(mEditMenu, 8, disabled, 'Select All/A');
		SetSelectAllItem(8);


		WindowOpen(StdWindow1, 0, 0, 396, 205, 'Scrolling a Field List', noGrowDocProc + wCenter, noGoAway, notModal);


		SetRect(theScrollRect, 20, 19, 361, 150);								{Define the scrollable area}
		NewPanelRect(511, theScrollRect, '', panBlackBorder, 0);				{Draw frame around area}
		NewScrollBar(1, 360, 19, 376, 150, scrlValueLimit, enabled, 1, 1, 91);	{Attach scroll bar}
		InsetRect(theScrollRect, 1, 1);											{Area _inside_ the frame will be scrolled later}

		NewButton(bCancel, 120, 170, 190, 190, 'Cancel', pushButProc, enabled, notSelected);
		NewButton(bOK, 210, 170, 280, 190, 'OK', pushButProc + bDefault, enabled, notSelected);


	{	Allocate the string handles for all the fields in the grid. Populate each one of the	}
	{	fields with an initial value in R1:C1 format. Each handle is only as big as it needs	}
	{	to be to store the current contents	}
		for theRow := 1 to 100 do
			for theColumn := 1 to 4 do
				begin
					NumToString(theRow, rowStr);
					NumToString(theColumn, colStr);
					theFieldStr := concat('R', rowStr, ':C', colStr);
					fieldStr[theRow, theColumn] := NewStrHandle(length(theFieldStr));
					fieldStr[theRow, theColumn]^^ := theFieldStr;
				end;


	{	Make the 'scroll to view' routine think that the required fields are out of view.	}
	{	It will then create the fields to match the scroll bar's current position		}
		prevScrollBarValue := 11;
		newScrollBarValue := 1;
		ScrollTheGrid;


		updateRgn := NewRgn;
		ExitTheDemo := false;
	end;




{	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	-	}
begin
{$IFC MWERKS}
{Toolbox initialization - - Done automatically by THINK Pascal}
	InitGraf(@qd.thePort);
	InitFonts;
	InitWindows;
	InitMenus;
	TEInit;
	InitDialogs(nil);
{$ENDC}

	if not InitToolsPlus(10, 1, initTE32KBuffer, initUseColor) then
		ExitToShell;

	ApplicationInitialization;

	while not ExitTheDemo do	{Main Event Loop}
		if PollSystem(Poll) then	{If an event is available, process the event}

			case Poll.What of

				doScrollBar:	{User is scrolling the list}
					begin
						case Poll.ScrollBar.Part of
							inUpButton: 
								SetScrollBarVal(1, prevScrollBarValue - 1);	{Scroll up by 1 line}
							inDownButton: 
								SetScrollBarVal(1, prevScrollBarValue + 1);	{Scroll down by 1 line}
							inPageUp: 
								SetScrollBarVal(1, prevScrollBarValue - 9);	{Scroll up by 9 lines}
							inPageDown: 
								SetScrollBarVal(1, prevScrollBarValue + 9);	{Scroll down by 9 lines}
							otherwise
						end;
						newScrollBarValue := GetScrollBarVal(1);
						if newScrollBarValue <> prevScrollBarValue then	{If scroll bar was moved}
							ScrollTheGrid;
					end;


				doKeyDown, doAutoKey: 
					if HaveTabInField then
						begin
							newScrollBarValue := GetScrollBarVal(1);
							SaveFieldString;
							if Poll.Modifiers.ShiftKey then	{Tab to PREVIOUS field}
								begin
									if ActiveFieldNumber > newScrollBarValue * 10 + 1 then	{Not the first visible field?}
										TabToField
									else if newScrollBarValue = GetScrollBarMin(1) then	{1st first in list	}
										begin
						{	When you shift-tab from the first field, we loop	}
						{	around the list to select the last field on the list	}
											newScrollBarValue := GetScrollBarMax(1);
											SetScrollBarVal(1, newScrollBarValue);
											ScrollTheGrid;
											ActivateField(1004, teSelectDefault);	{Activate the last field in the list}
										end
									else
										begin	{Top visible field and list can be scrolled	}
											newScrollBarValue := newScrollBarValue - 1;	{Scroll up by 1 line}
											SetScrollBarVal(1, newScrollBarValue);
											ScrollTheGrid;
											TabToField;
										end;
								end

							else	{Tab to NEXT field}
								if ActiveFieldNumber < (newScrollBarValue + 9) * 10 + 4 then	{Not the last visible field?}
									TabToField
								else if newScrollBarValue = GetScrollBarMax(1) then	{Last field in list}
									begin
						{	When you tab from the last field, we loop around	}
						{	the list to select the first field on the list	}
										newScrollBarValue := GetScrollBarMin(1);
										SetScrollBarVal(1, newScrollBarValue);
										ScrollTheGrid;
										ActivateField(11, teSelectDefault);	{Activate first field in the list}
									end
								else
									begin
										newScrollBarValue := newScrollBarValue + 1;	{Scroll down by 1 line}
										SetScrollBarVal(1, newScrollBarValue);
										ScrollTheGrid;
										TabToField;
									end;
						end;


				doClickField: 
					begin
						SaveFieldString;
						ClickInField;
					end;


				doRefresh: 
					DrawGridLines;


				doButton: 
					ExitTheDemo := true;


				doMenu: 
					ExitTheDemo := true;

				otherwise	{All other events are ignored}
			end
end.